/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The context for the function of the series label visual.
 */
export interface SeriesLabelsContentArgs {
    /**
     * The label text.
     */
    text: string;
    /**
     * The original data item used to construct the point. If binding to an array, it will be `null`.
     */
    dataItem: any;
    /**
     * The category name. Available for the Area, Bar, Column, Bubble, Donut, Funnel, Pyramid, Line, and Pie
     * series.
     */
    category: any;
    /**
     * The point value. Can be a number or object containing each bound field.
     */
    value: any;
    /**
     * The point value that is represented as a percentage value.
     * Available only for the Donut, Pie, and 100% stacked charts.
     */
    percentage?: number;
    /**
     * The cumulative point value on the stack.
     * Available only for the stackable series.
     */
    stackValue?: number;
    /**
     * The sum of point values from the last `runningTotal` summary point onwards.
     * Available for the Waterfall series.
     */
    runningTotal?: number;
    /**
     * The sum of all previous series values.
     * Available for the Waterfall series.
     */
    total?: number;
    /**
     * The data series configuration object.
     */
    series: any;
}
