/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChartComponent } from '../chart.component';
import { drawing, geometry } from '@progress/kendo-drawing';
/**
 * The context for the function of the series label visual.
 */
export interface SeriesLabelsVisualArgs {
    /**
     * A function that can be used to get the default visual.
     */
    createVisual: () => drawing.Element;
    /**
     * The label options.
     */
    options: any;
    /**
     * The rectangle that defines the normal position of the visual.
     */
    rect: geometry.Rect;
    /**
     * The instance of the Chart component.
     */
    sender: ChartComponent;
    /**
     * The label text.
     */
    text: string;
    /**
     * The point data item.
     */
    dataItem: any;
    /**
     * The point category.
     */
    category: any;
    /**
     * The point value.
     */
    value: any;
    /**
     * The point value that is represented as a percentage value.
     * Available only for the Donut, Pie, and 100% stacked charts.
     */
    percentage?: number;
    /**
     * The cumulative point value on the stack.
     * Available only for the stackable series.
     */
    stackValue?: number;
    /**
     * The sum of point values from the last `runningTotal` summary point onwards.
     * Available for the Waterfall series.
     */
    runningTotal?: number;
    /**
     * The sum of all previous series values.
     * Available for the Waterfall series.
     */
    total?: number;
    /**
     * The point series.
     */
    series: any;
}
