/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnChanges, OnDestroy, OnInit, SimpleChanges } from '@angular/core';
import { BreadCrumbComponent, BreadCrumbItem } from '@progress/kendo-angular-navigation';
import { ChartComponent } from './index';
import * as i0 from "@angular/core";
/**
 * Navigation Breadcrumb component for Drilldown Charts.
 *
 * Use this component to implement navigation for [Drilldown Charts](slug:drilldown_chart_charts).
 * Use the `chart` input to link the Breadcrumb to the Chart instance.
 *
 */
export declare class ChartBreadcrumbComponent implements OnInit, OnChanges, OnDestroy {
    /**
     * The Chart instance to link to.
     */
    chart: ChartComponent;
    /**
     * The definition of the breadcrumb root item.
     *
     * The default value is `{ icon: 'home', svgIcon: homeIcon, title: 'Home' }`.
     * (homeIcon is imported from '@progress/kendo-svg-icons')
     */
    rootItem: BreadCrumbItem;
    /**
     * @hidden
     */
    items: BreadCrumbItem[];
    breadcrumb: BreadCrumbComponent;
    private subscription;
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    ngOnDestroy(): void;
    /**
     * @hidden
     */
    onItemClick(target: BreadCrumbItem): void;
    private onDrilldown;
    private onDrilldownLevelChange;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChartBreadcrumbComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChartBreadcrumbComponent, "kendo-chart-breadcrumb", ["kendoChartBreadcrumb"], { "chart": { "alias": "chart"; "required": false; }; "rootItem": { "alias": "rootItem"; "required": false; }; }, {}, never, never, true, never>;
}
