/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../common/configuration.service';
import { AxisLine, AxisTicks, GridLines, PlotBand } from '../common/property-types';
import { AxisDefaults, AxisDefaultsCrosshair, AxisDefaultsLabels, AxisDefaultsTitle } from '../common/property-types';
import { SettingsComponent } from '../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The default options for all Chart axes ([see example](slug:axes_chart_charts#toc-default-axis-configuration)).
 * Accepts the options which are supported by [`categoryAxis`](slug:api_charts_categoryaxisitemcomponent),
 * [`valueAxis`](slug:api_charts_valueaxisitemcomponent),
 * [`xAxis`](slug:api_charts_xaxisitemcomponent),
 * and [`yAxis`](slug:api_charts_yaxisitemcomponent).
 *
 */
export declare class AxisDefaultsComponent extends SettingsComponent implements AxisDefaults {
    configurationService: ConfigurationService;
    background: string;
    color: string;
    line: AxisLine;
    majorGridLines: GridLines;
    majorTicks: AxisTicks;
    minorGridLines: GridLines;
    minorTicks: AxisTicks;
    /**
     * If set to `true`, the Chart prevents the axis range from snapping to zero.
     * Setting it to `false`, forces the axis range to snap to zero.
     * @default false
     */
    narrowRange: boolean;
    pane: string;
    plotBands: PlotBand[];
    /**
     * If set to `true`, the axis direction is reversed. By default, categories are listed from left to
     * right and from bottom to top.
     * @default false
     */
    reverse: boolean;
    /**
     * The angle (degrees) of the first category on the axis.
     * Angles increase clockwise with zero to the left. Negative values are acceptable.
     * @default 90
     */
    startAngle: number;
    /**
     * If set to `true`, the Chart displays the axis.
     * @default true
     */
    visible: boolean;
    crosshair: AxisDefaultsCrosshair;
    labels: AxisDefaultsLabels;
    title: AxisDefaultsTitle;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<AxisDefaultsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AxisDefaultsComponent, "kendo-chart-axis-defaults", never, { "background": { "alias": "background"; "required": false; }; "color": { "alias": "color"; "required": false; }; "line": { "alias": "line"; "required": false; }; "majorGridLines": { "alias": "majorGridLines"; "required": false; }; "majorTicks": { "alias": "majorTicks"; "required": false; }; "minorGridLines": { "alias": "minorGridLines"; "required": false; }; "minorTicks": { "alias": "minorTicks"; "required": false; }; "narrowRange": { "alias": "narrowRange"; "required": false; }; "pane": { "alias": "pane"; "required": false; }; "plotBands": { "alias": "plotBands"; "required": false; }; "reverse": { "alias": "reverse"; "required": false; }; "startAngle": { "alias": "startAngle"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "crosshair": { "alias": "crosshair"; "required": false; }; "labels": { "alias": "labels"; "required": false; }; "title": { "alias": "title"; "required": false; }; }, {}, never, never, true, never>;
}
