/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { AxisLabelContentArgs, AxisLabelVisualArgs, LabelRotation, Margin, Padding } from '../../common/property-types';
import { AxisDefaultsLabels } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The configuration of the axis labels ([see example](slug:axes_chart_charts#toc-default-axis-configuration)).
 */
export declare class AxisDefaultsLabelsComponent extends SettingsComponent implements AxisDefaultsLabels {
    configurationService: ConfigurationService;
    content: (e: AxisLabelContentArgs) => string;
    /**
     * The font style of the labels.
     * @default '12px sans-serif'
     */
    font: string;
    /**
     * The format for displaying the labels. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of `IntlService`.
     * Contains one placeholder (`"{0}"`) which represents the category value.
     * @default '{0}'
     */
    format: string;
    /**
     * The margin of the labels. A numeric value sets all margins.
     * @default 0
     */
    margin: Margin | number;
    /**
     * If set to `true`, the Chart mirrors the axis labels and ticks.
     * If the labels are normally on the left side of the axis,
     * the mirroring of the axis renders them to the right.
     * @default false
     */
    mirror: boolean;
    /**
     * The padding of the labels. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    /**
     * The rotation angle of the labels. By default, the labels are not rotated.
     * If the axis is horizontal, can be set to `"auto"`.
     * In this case, the labels are rotated only if the slot size is not sufficient for the entire labels.
     * @default 0
     */
    rotation: LabelRotation | number | 'auto';
    /**
     * The number of labels to skip. By default, no labels are skipped.
     * @default 0
     */
    skip: number;
    /**
     * The label-rendering step&mdash;renders every n<sup>th</sup> label. By default, every label is rendered.
     * @default 1
     */
    step: number;
    /**
     * If set to `true`, the Chart displays the axis labels. By default, the axis labels are visible.
     * @default true
     */
    visible: boolean;
    visual: (e: AxisLabelVisualArgs) => drawing.Element;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<AxisDefaultsLabelsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<AxisDefaultsLabelsComponent, "kendo-chart-axis-defaults-labels", never, { "content": { "alias": "content"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "mirror": { "alias": "mirror"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "rotation": { "alias": "rotation"; "required": false; }; "skip": { "alias": "skip"; "required": false; }; "step": { "alias": "step"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; }, {}, never, never, true, never>;
}
