/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnDestroy } from '@angular/core';
import { IntlService } from '@progress/kendo-angular-intl';
import { CollectionItemComponent } from '../common/collection-item.component';
import { CollectionService } from '../common/collection.service';
import { ConfigurationService } from '../common/configuration.service';
import { CategoryAxisRangeLabels } from '../common/property-types';
import { AutoBaseUnitSteps, AxisLine, AxisTicks, CategoryBaseUnit, GridLines, PlotBand, WeekStartDay } from '../common/property-types';
import { CategoryAxis, CategoryAxisCrosshair, CategoryAxisLabels, CategoryAxisNotes, CategoryAxisSelect, CategoryAxisTitle } from '../common/property-types';
import * as i0 from "@angular/core";
/**
 * The configuration component for a category axis ([see example]({% slug axes_chart_charts %})).
 */
export declare class CategoryAxisItemComponent extends CollectionItemComponent implements CategoryAxis, OnDestroy {
    protected configurationService: ConfigurationService;
    protected collectionService: CollectionService;
    private intl;
    autoBaseUnitSteps: AutoBaseUnitSteps;
    axisCrossingValue: any | any[];
    background: string;
    baseUnit: CategoryBaseUnit;
    baseUnitStep: number | 'auto';
    categories: any[];
    color: string;
    justified: boolean;
    line: AxisLine;
    majorGridLines: GridLines;
    majorTicks: AxisTicks;
    max: any;
    /**
     * The maximum number of groups (categories) to display when
     * [`categoryAxis.baseUnit`]({% slug api_charts_categoryaxis %}#toc-baseunit) is set to `"fit"` or
     * [`categoryAxis.baseUnitStep`]({% slug api_charts_categoryaxis %}#toc-baseunitstep) is set to `"auto"`.
     * @default 10
     */
    maxDateGroups: number;
    maxDivisions: number;
    min: any;
    minorGridLines: GridLines;
    minorTicks: AxisTicks;
    /**
     * The unique axis name. Used to associate a series with a category axis,
     * which utilizes the [`series.categoryAxis`]({% slug api_charts_series %}#toc-categoryaxis) option.
     * @default 'primary'
     */
    name: string;
    pane: string;
    plotBands: PlotBand[];
    /**
     * If set to `true`, the category axis direction is reversed.
     * By default, categories are listed from left to right and from bottom to top.
     * @default false
     */
    reverse: boolean;
    /**
     * If set to `true`, the Chart rounds the first and last date to the nearest base unit.
     * @default true
     */
    roundToBaseUnit: boolean;
    /**
     * The angle (degrees) of the first category on the axis.
     * Angles increase clockwise with zero to the left. Negative values are acceptable.
     * @default 90
     */
    startAngle: number;
    /**
     * The category axis type.
     * The supported values include `category` for a discrete category axis and `date` for a specialized axis for displaying chronological data.
     * @default 'category'
     */
    type: 'category' | 'date';
    /**
     * If set to `true`, the Chart displays the category axis. By default, the category axis is visible.
     * @default true
     */
    visible: boolean;
    /**
     * The week start day when the `baseUnit` is set to `"weeks"`.
     * @default 'Sunday'
     */
    weekStartDay: WeekStartDay;
    crosshair: CategoryAxisCrosshair;
    labels: CategoryAxisLabels;
    notes: CategoryAxisNotes;
    select: CategoryAxisSelect;
    title: CategoryAxisTitle;
    rangeLabels: CategoryAxisRangeLabels;
    private intlSubscription;
    constructor(configurationService: ConfigurationService, collectionService: CollectionService, intl: IntlService, localeId: string);
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CategoryAxisItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CategoryAxisItemComponent, "kendo-chart-category-axis-item", never, { "autoBaseUnitSteps": { "alias": "autoBaseUnitSteps"; "required": false; }; "axisCrossingValue": { "alias": "axisCrossingValue"; "required": false; }; "background": { "alias": "background"; "required": false; }; "baseUnit": { "alias": "baseUnit"; "required": false; }; "baseUnitStep": { "alias": "baseUnitStep"; "required": false; }; "categories": { "alias": "categories"; "required": false; }; "color": { "alias": "color"; "required": false; }; "justified": { "alias": "justified"; "required": false; }; "line": { "alias": "line"; "required": false; }; "majorGridLines": { "alias": "majorGridLines"; "required": false; }; "majorTicks": { "alias": "majorTicks"; "required": false; }; "max": { "alias": "max"; "required": false; }; "maxDateGroups": { "alias": "maxDateGroups"; "required": false; }; "maxDivisions": { "alias": "maxDivisions"; "required": false; }; "min": { "alias": "min"; "required": false; }; "minorGridLines": { "alias": "minorGridLines"; "required": false; }; "minorTicks": { "alias": "minorTicks"; "required": false; }; "name": { "alias": "name"; "required": false; }; "pane": { "alias": "pane"; "required": false; }; "plotBands": { "alias": "plotBands"; "required": false; }; "reverse": { "alias": "reverse"; "required": false; }; "roundToBaseUnit": { "alias": "roundToBaseUnit"; "required": false; }; "startAngle": { "alias": "startAngle"; "required": false; }; "type": { "alias": "type"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "weekStartDay": { "alias": "weekStartDay"; "required": false; }; "crosshair": { "alias": "crosshair"; "required": false; }; "labels": { "alias": "labels"; "required": false; }; "notes": { "alias": "notes"; "required": false; }; "select": { "alias": "select"; "required": false; }; "title": { "alias": "title"; "required": false; }; "rangeLabels": { "alias": "rangeLabels"; "required": false; }; }, {}, never, never, true, never>;
}
