/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../../common/configuration.service';
import { SettingsComponent } from '../../common/settings.component';
import { Border, Padding } from '../../common/property-types';
import { CategoryAxisCrosshairTooltip } from '../../common/property-types';
import * as i0 from "@angular/core";
/**
 * The options of the crosshair tooltip ([see example]({% slug crosshairs_chart_charts %})).
 * The crosshair tooltip is displayed when the `visible` option is set to `true`.
 */
export declare class CategoryAxisCrosshairTooltipComponent extends SettingsComponent implements CategoryAxisCrosshairTooltip {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    /**
     * The tooltip font.
     * @default '12px sans-serif'
     */
    font: string;
    /**
     * The format used to display the tooltip. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of IntlService.
     * Contains one placeholder (`"{0}"`) which represents the category value.
     * @default '{0}'
     */
    format: string;
    /**
     * The padding of the crosshair tooltip. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    /**
     * If set to `true`, the Chart displays the category axis crosshair tooltip.
     * By default, the category axis crosshair tooltip is not visible.
     * @default false
     */
    visible: boolean;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<CategoryAxisCrosshairTooltipComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CategoryAxisCrosshairTooltipComponent, "kendo-chart-category-axis-item-crosshair-tooltip", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; }, {}, never, never, true, never>;
}
