/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../../common/configuration.service';
import { AxisNoteContentArgs, Border, NoteLabelPosition } from '../../common/property-types';
import { CategoryAxisNotesLabel } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The label of the notes.
 */
export declare class CategoryAxisNotesLabelComponent extends SettingsComponent implements CategoryAxisNotesLabel {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    content: (e: AxisNoteContentArgs) => string;
    /**
     * The font style of the label.
     * @default '12px, sans-serif'
     */
    font: string;
    /**
     * The format for displaying the notes label. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of IntlService.
     * Contains one placeholder (`"{0}"`) which represents the category value.
     * @default '{0}'
     */
    format: string;
    /**
     * The position of the label.
     * @default "inside"
     */
    position: NoteLabelPosition;
    /**
     * The rotation angle of the label. By default, the label is not rotated.
     * @default 0
     */
    rotation: number;
    /**
     * If set to `true`, the Chart displays the category notes label.
     * By default, the category notes label is visible.
     * @default true
     */
    visible: boolean;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<CategoryAxisNotesLabelComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CategoryAxisNotesLabelComponent, "kendo-chart-category-axis-item-notes-label", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "content": { "alias": "content"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "position": { "alias": "position"; "required": false; }; "rotation": { "alias": "rotation"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; }, {}, never, never, true, never>;
}
