/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../common/configuration.service';
import { Border, Margin } from '../common/property-types';
import { ChartArea } from '../common/property-types';
import { SettingsComponent } from '../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The configuration options of the Chart area.
 * Represents the entire visible area of the Chart
 * ([see example]({% slug chartarea_chart_charts %})).
 */
export declare class ChartAreaComponent extends SettingsComponent implements ChartArea {
    configurationService: ConfigurationService;
    /**
     * The background color of the Chart area. Accepts a valid CSS color string, including hex and rgb.
     * @default 'white'
     */
    background: string;
    border: Border;
    /**
     * The height of the Chart area.
     * @default 400
     */
    height: number;
    /**
     * The margin of the Chart area. A numeric value sets all margins.
     * @default 5
     */
    margin: Margin | number;
    /**
     * The background opacity of the Chart area. By default, the background is opaque.
     * @default 1
     */
    opacity: number;
    /**
     * The width of the Chart area.
     * @default 600
     */
    width: number;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<ChartAreaComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ChartAreaComponent, "kendo-chart-area", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "height": { "alias": "height"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "opacity": { "alias": "opacity"; "required": false; }; "width": { "alias": "width"; "required": false; }; }, {}, never, never, true, never>;
}
