/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { SettingsComponent } from '../../common/settings.component';
import { Border, Margin, PaneDefaultsTitle } from '../../common/property-types';
import * as i0 from "@angular/core";
/**
 * The configuration of the pane default title.
 */
export declare class PaneDefaultsTitleComponent extends SettingsComponent implements PaneDefaultsTitle {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    /**
     * The font style of the title.
     * @default '16px sans-serif'
     */
    font: string;
    /**
     * The margin of the title. A numeric value sets all margins.
     * @default 5
     */
    margin: Margin | number;
    /**
     * The position of the title.
     *
     * The positioning of the axis title can be set to `left` for left positioning, `right` for right positioning (both applicable to the horizontal axis), or `center` for positioning in the center.
     * @default 'center'
     */
    position: 'left' | 'right' | 'center';
    /**
     * If set to `true`, the Chart displays the pane title.
     * @default true
     */
    visible: boolean;
    visual: (e: any) => drawing.Element;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<PaneDefaultsTitleComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PaneDefaultsTitleComponent, "kendo-chart-pane-defaults-title", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "font": { "alias": "font"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "position": { "alias": "position"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; }, {}, never, never, true, never>;
}
