/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { CollectionItemComponent } from '../common/collection-item.component';
import { CollectionService } from '../common/collection.service';
import { ConfigurationService } from '../common/configuration.service';
import { Border, Margin, Padding } from '../common/property-types';
import { Pane, PanesTitle } from '../common/property-types';
import * as i0 from "@angular/core";
/**
 * The configuration component for a Chart pane.
 *
 * @example
 * ```html
 * <kendo-chart>
 *   <kendo-chart-panes>
 *     <kendo-chart-pane
 *         name="top"
 *         background="pink"
 *         [border]="{ color: 'black', dashType: 'dash', width: 2 }">
 *     </kendo-chart-pane>
 *   </kendo-chart-panes>
 * </kendo-chart>
 * ```
 */
export declare class PaneComponent extends CollectionItemComponent implements Pane {
    protected configurationService: ConfigurationService;
    protected collectionService: CollectionService;
    background: string;
    border: Border;
    clip: boolean;
    height: number;
    /**
     * The margin of the pane. A numeric value sets all margins.
     * @default 0
     */
    margin: Margin | number;
    name: string;
    /**
     * The padding of the pane. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    title: string | PanesTitle;
    constructor(configurationService: ConfigurationService, collectionService: CollectionService);
    static ɵfac: i0.ɵɵFactoryDeclaration<PaneComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PaneComponent, "kendo-chart-pane, kendo-chart-panes-item", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "clip": { "alias": "clip"; "required": false; }; "height": { "alias": "height"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "name": { "alias": "name"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "title": { "alias": "title"; "required": false; }; }, {}, never, never, true, never>;
}
