/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../common/configuration.service';
import { Border, Margin, Padding } from '../common/property-types';
import { PlotArea } from '../common/property-types';
import { SettingsComponent } from '../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The configuration options of the plot area
 * ([see example]({% slug plotarea_chart_charts %})).
 * The plot area is the area which displays the series.
 */
export declare class PlotAreaComponent extends SettingsComponent implements PlotArea {
    configurationService: ConfigurationService;
    /**
     * The background color of the Chart plot area.
     * Accepts a valid CSS color string, including HEX and RGB.
     * @default 'white'
     */
    background: string;
    border: Border;
    /**
     * The margin of the plot area. A numeric value sets all margins.
     * @default 5
     */
    margin: Margin | number;
    /**
     * The background opacity of the plot area. By default, the background is opaque.
     * @default 1
     */
    opacity: number;
    /**
     * The padding of the plot area. A numeric value sets all paddings.
     * The default padding for the Pie, Donut, Radar, and Polar Charts is proportional of the Chart size.
     * @default 5
     */
    padding: Padding | number;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<PlotAreaComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<PlotAreaComponent, "kendo-chart-plot-area", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "opacity": { "alias": "opacity"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; }, {}, never, never, true, never>;
}
