/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { Border, Margin, Padding, SeriesLabelsContentArgs, SeriesLabelsVisualArgs } from '../../common/property-types';
import { SeriesDefaultsLabels, SeriesDefaultsLabelsFrom, SeriesDefaultsLabelsTo } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The configuration of the Chart series label.
 */
export declare class SeriesDefaultsLabelsComponent extends SettingsComponent implements SeriesDefaultsLabels {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    content: (e: SeriesLabelsContentArgs) => string;
    /**
     * The font style of the labels.
     * @default '12px sans-serif'
     */
    font: string;
    /**
     * The format of the labels. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of `IntlService`.
     * @default '{0}'
     */
    format: string;
    /**
     * The margin of the labels. A numeric value sets all margins.
     * @default 0
     */
    margin: Margin | number;
    /**
     * The padding of the labels. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    /**
     * If set to `true`, the Chart displays the series labels.
     * @default false
     */
    visible: boolean;
    visual: (e: SeriesLabelsVisualArgs) => drawing.Element;
    from: SeriesDefaultsLabelsFrom;
    to: SeriesDefaultsLabelsTo;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<SeriesDefaultsLabelsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SeriesDefaultsLabelsComponent, "kendo-chart-series-defaults-labels", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "content": { "alias": "content"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; "from": { "alias": "from"; "required": false; }; "to": { "alias": "to"; "required": false; }; }, {}, never, never, true, never>;
}
