/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { Border, Margin, Padding, SeriesLabelsAlignment, SeriesLabelsContentArgs, SeriesLabelsVisualArgs } from '../../common/property-types';
import { SeriesLabels, SeriesLabelsFrom, SeriesLabelsPosition, SeriesLabelsTo } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The configuration of the Chart series label
 * ([see example]({% slug labels_chart_charts %})).
 */
export declare class SeriesLabelsComponent extends SettingsComponent implements SeriesLabels {
    configurationService: ConfigurationService;
    align: SeriesLabelsAlignment;
    background: string;
    border: Border;
    color: string;
    content: (e: SeriesLabelsContentArgs) => string;
    ariaContent: (e: SeriesLabelsContentArgs) => string;
    /**
     * The distance between the labels when [`series.type`]({% slug api_charts_series %}#toc-type) is set to `"donut"` or `"pie"`.
     * @default 35
     */
    distance: number;
    /**
     * The font style of the labels.
     * @default '12px sans-serif'
     */
    font: string;
    /**
     * The format of the labels. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of the `IntlService`.
     * @default '{0}'
     */
    format: string;
    /**
     * The margin of the labels. A numeric value sets all margins.
     * @default 5
     */
    margin: Margin | number;
    /**
     * The padding of the labels. A numeric value sets all paddings.
     * Bar and Column series always apply full padding and ignore this setting.
     * @default 0
     */
    padding: Padding | number;
    /**
     * The position of the labels.
     */
    position: SeriesLabelsPosition;
    rotation: number;
    /**
     * If set to `true`, the Chart displays the series labels.
     * @default false
     */
    visible: boolean;
    visual: (e: SeriesLabelsVisualArgs) => drawing.Element;
    from: SeriesLabelsFrom;
    to: SeriesLabelsTo;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<SeriesLabelsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SeriesLabelsComponent, "kendo-chart-series-item-labels", never, { "align": { "alias": "align"; "required": false; }; "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "content": { "alias": "content"; "required": false; }; "ariaContent": { "alias": "ariaContent"; "required": false; }; "distance": { "alias": "distance"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "position": { "alias": "position"; "required": false; }; "rotation": { "alias": "rotation"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; "from": { "alias": "from"; "required": false; }; "to": { "alias": "to"; "required": false; }; }, {}, never, never, true, never>;
}
