/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../../common/configuration.service';
import { Border, Margin, Padding, SeriesLabelsContentArgs } from '../../common/property-types';
import { SeriesLabelsFrom } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The `from` label configuration of the Chart series.
 */
export declare class SeriesLabelsFromComponent extends SettingsComponent implements SeriesLabelsFrom {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    content: (e: SeriesLabelsContentArgs) => string;
    /**
     * The font style of the `from` labels.
     * @default '12px sans-serif'
     */
    font: string;
    /**
     * The format of the `from` labels. Uses the `IntlService` [`format`]({% slug api_intl_intlservice %}#toc-format) method.
     * @default '{0}'
     */
    format: string;
    /**
     * The margin of the `from` labels. A numeric value sets all margins.
     * @default 5
     */
    margin: Margin | number;
    /**
     * The padding of the `from` labels. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    position: 'center' | 'insideBase' | 'insideEnd' | 'outsideEnd';
    /**
     * If set to `true`, the Chart displays the series `from` labels.
     * @default false
     */
    visible: boolean;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<SeriesLabelsFromComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SeriesLabelsFromComponent, "kendo-chart-series-item-labels-from", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "content": { "alias": "content"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "position": { "alias": "position"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; }, {}, never, never, true, never>;
}
