/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { Border, MarkersVisualArgs, MarkerType } from '../../common/property-types';
import { SeriesMarkers } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The configuration of the Chart series marker.
 *
 * @example
 * ```html
 * <kendo-chart ...>
 *   <kendo-chart-series>
 *     <kendo-chart-series-item type="line"...>
 *       <kendo-chart-series-item-markers background="blue"> </kendo-chart-series-item-markers>
 *     </kendo-chart-series-item>
 *   </kendo-chart-series>
 * </kendo-chart>
 * ```
 */
export declare class SeriesMarkersComponent extends SettingsComponent implements SeriesMarkers {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    rotation: number;
    /**
     * The marker size in pixels.
     * @default 6
     */
    size: number;
    /**
     * The shape of the series markers.
     * @default 'cirlce'
     */
    type: MarkerType;
    /**
     * If set to `true`, the Chart displays the series markers.
     * @default true
     */
    visible: boolean;
    visual: (e: MarkersVisualArgs) => drawing.Element;
    from: SeriesMarkers;
    to: SeriesMarkers;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<SeriesMarkersComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SeriesMarkersComponent, "kendo-chart-series-item-markers", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "rotation": { "alias": "rotation"; "required": false; }; "size": { "alias": "size"; "required": false; }; "type": { "alias": "type"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; "from": { "alias": "from"; "required": false; }; "to": { "alias": "to"; "required": false; }; }, {}, never, never, true, never>;
}
