/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { NoteLine, NotePosition, SeriesNoteVisualArgs } from '../../common/property-types';
import { SeriesNotes, SeriesNotesIcon, SeriesNotesLabel } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The series notes configuration
 * ([see example]({% slug notes_chart_charts %})).
 *
 * @example
 * ```html
 * <kendo-chart ...>
 *   <kendo-chart-series>
 *     <kendo-chart-series-item type="line" [data]="data"...>
 *       <kendo-chart-series-item-notes [icon]="{type: 'square'}"> </kendo-chart-series-item-notes>
 *     </kendo-chart-series-item>
 *   </kendo-chart-series>
 * </kendo-chart>
 * ```
 */
export declare class SeriesNotesComponent extends SettingsComponent implements SeriesNotes {
    configurationService: ConfigurationService;
    line: NoteLine;
    position: NotePosition;
    visual: (e: SeriesNoteVisualArgs) => drawing.Element;
    icon: SeriesNotesIcon;
    label: SeriesNotesLabel;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<SeriesNotesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SeriesNotesComponent, "kendo-chart-series-item-notes", never, { "line": { "alias": "line"; "required": false; }; "position": { "alias": "position"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; "icon": { "alias": "icon"; "required": false; }; "label": { "alias": "label"; "required": false; }; }, {}, never, never, true, never>;
}
