/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../common/configuration.service';
import { Border, Margin, Padding } from '../common/property-types';
import { Subtitle } from '../common/property-types';
import { SettingsComponent } from '../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The configuration options of the Chart subtitle or text
 * ([see example]({% slug title_chart_charts %})).
 *
 * @example
 * ```html
 * <kendo-chart [categoryAxis]="{ categories: categories }">
 *     <kendo-chart-subtitle text="/GDP annual %/"></kendo-chart-subtitle>
 * </kendo-chart>
 * ```
 */
export declare class SubtitleComponent extends SettingsComponent implements Subtitle {
    configurationService: ConfigurationService;
    align: 'center' | 'left' | 'right';
    /**
     * The background color of the subtitle. Accepts a valid CSS color string, including HEX and RGB.
     *
     * @default 'white'
     */
    background: string;
    border: Border;
    color: string;
    /**
     * The font of the subtitle.
     *
     * @default '12px sans-serif'
     */
    font: string;
    margin: Margin | number;
    /**
     * The padding of the subtitle. A numeric value sets all paddings.
     *
     * @default 5
     */
    padding: Padding | number;
    /**
     * The position of the subtitle.
     *
     * @default 'top'
     */
    position: 'top' | 'bottom';
    text: string;
    /**
     * If set to `true`, the Chart displays the subtitle.
     *
     * @default true
     */
    visible: boolean;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<SubtitleComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SubtitleComponent, "kendo-chart-subtitle", never, { "align": { "alias": "align"; "required": false; }; "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "font": { "alias": "font"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "position": { "alias": "position"; "required": false; }; "text": { "alias": "text"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; }, {}, never, never, true, never>;
}
