/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../common/configuration.service';
import { Border, Margin, Padding } from '../common/property-types';
import { Title } from '../common/property-types';
import { SettingsComponent } from '../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The configuration options of the Chart title or text
 * ([see example]({% slug title_chart_charts %})).
 *
 * @example
 * ```html
 * <kendo-chart [categoryAxis]="{ categories: categories }">
 *     <kendo-chart-title text="Title Text" [padding]="{bottom: 20}"></kendo-chart-title>
 *     ...
 * </kendo-chart>
 * ```
 */
export declare class TitleComponent extends SettingsComponent implements Title {
    configurationService: ConfigurationService;
    /**
     * The alignment of the title.
     * The alignment options for text include `center` for middle alignment, `left` for left alignment, and `right` for right alignment, allowing for flexible positioning of the title.
     *
     * @default 'center'
     */
    align: 'center' | 'left' | 'right';
    /**
     * The background color of the title. Accepts a valid CSS color string, including HEX and RGB.
     *
     * @default 'white'
     */
    background: string;
    border: Border;
    color: string;
    /**
     * The font of the title.
     *
     * @default '16px sans-serif'
     */
    font: string;
    margin: Margin | number;
    /**
     * The padding of the title. A numeric value sets all paddings.
     *
     * @default 5
     */
    padding: Padding | number;
    /**
     * The position of the title.
     * The positioning options for titles include `bottom` for positioning at the bottom and `top` for positioning at the top, providing flexibility in title placement.
     *
     * @default 'top'
     */
    position: 'top' | 'bottom';
    text: string;
    description: string;
    /**
     * If set to `true`, the Chart displays the title.
     *
     * @default true
     */
    visible: boolean;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<TitleComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TitleComponent, "kendo-chart-title", never, { "align": { "alias": "align"; "required": false; }; "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "font": { "alias": "font"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "position": { "alias": "position"; "required": false; }; "text": { "alias": "text"; "required": false; }; "description": { "alias": "description"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; }, {}, never, never, true, never>;
}
