/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterContentChecked } from '@angular/core';
import { ConfigurationService } from '../common/configuration.service';
import { Border, Padding } from '../common/property-types';
import { Tooltip } from '../common/property-types';
import { SettingsComponent } from '../common/settings.component';
import { TooltipTemplateService } from '../common/tooltip-template.service';
import { SeriesTooltipTemplateDirective } from './tooltip/series-tooltip-template.directive';
import { SharedTooltipTemplateDirective } from './tooltip/shared-tooltip-template.directive';
import * as i0 from "@angular/core";
/**
 * The configuration options of the Chart series tooltip
 * ([see example]({% slug tooltips_chart_charts %})).
 */
export declare class TooltipComponent extends SettingsComponent implements Tooltip, AfterContentChecked {
    configurationService: ConfigurationService;
    private templateService;
    background: string;
    border: Border;
    color: string;
    /**
     * The font of the tooltip.
     * @default '12px sans-serif'
     */
    font: string;
    format: string;
    /**
     * The opacity of the tooltip.
     * @default 1
     */
    opacity: number;
    padding: Padding | number;
    /**
     * If set to `true`, the Chart displays a single tooltip for every category.
     * @default false
     */
    shared: boolean;
    /**
     * If set to `true`, the Chart displays the series tooltip.
     * @default false
     */
    visible: boolean;
    seriesTooltipTemplate: SeriesTooltipTemplateDirective;
    sharedTooltipTemplate: SharedTooltipTemplateDirective;
    constructor(configurationService: ConfigurationService, templateService: TooltipTemplateService);
    ngAfterContentChecked(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<TooltipComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<TooltipComponent, "kendo-chart-tooltip", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "opacity": { "alias": "opacity"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "shared": { "alias": "shared"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; }, {}, ["seriesTooltipTemplate", "sharedTooltipTemplate"], never, true, never>;
}
