/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { CollectionItemComponent } from '../common/collection-item.component';
import { CollectionService } from '../common/collection.service';
import { ConfigurationService } from '../common/configuration.service';
import { AxisLine, AxisTicks, GridLines, PlotBand } from '../common/property-types';
import { ValueAxis, ValueAxisCrosshair, ValueAxisLabels, ValueAxisNotes, ValueAxisTitle } from '../common/property-types';
import * as i0 from "@angular/core";
/**
 * The configuration component for a value axis.
 */
export declare class ValueAxisItemComponent extends CollectionItemComponent implements ValueAxis {
    protected configurationService: ConfigurationService;
    protected collectionService: CollectionService;
    axisCrossingValue: any | any[];
    background: string;
    color: string;
    line: AxisLine;
    majorGridLines: GridLines;
    majorTicks: AxisTicks;
    majorUnit: number;
    /**
     * The maximum value of the axis.
     * @default 1
     */
    max: any;
    /**
     * The minimum value of the axis.
     * @default 0
     */
    min: any;
    minorGridLines: GridLines;
    minorTicks: AxisTicks;
    minorUnit: number;
    /**
     * The unique axis name. Used to associate a series with a value axis by using the [`series.axis`]({% slug api_charts_series %}#toc-axis) option.
     * @default 'primary'
     */
    name: string;
    /**
     * If set to `true`, the Chart prevents the automatic axis range from snapping to zero.
     * Setting it to `false` forces the automatic axis range to snap to zero.
     * @default true
     */
    narrowRange: boolean;
    pane: string;
    plotBands: PlotBand[];
    /**
     * If set to `true`, the value axis direction is reversed.
     * By default, the categories are listed from left to right and from bottom to top.
     *
     * Radar and Polar Charts do not support reverse value axes.
     * @default false
     */
    reverse: boolean;
    /**
     * The axis type.
     *
     * The "numeric" value refers to a numeric axis, while "log" represents a logarithmic axis.
     * @default 'numeric'
     *
     */
    type: 'numeric' | 'log';
    /**
     * If set to `true`, the Chart displays the value axis. By default, the value axis is visible.
     * @default true
     */
    visible: boolean;
    crosshair: ValueAxisCrosshair;
    labels: ValueAxisLabels;
    notes: ValueAxisNotes;
    title: ValueAxisTitle;
    constructor(configurationService: ConfigurationService, collectionService: CollectionService);
    static ɵfac: i0.ɵɵFactoryDeclaration<ValueAxisItemComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ValueAxisItemComponent, "kendo-chart-value-axis-item", never, { "axisCrossingValue": { "alias": "axisCrossingValue"; "required": false; }; "background": { "alias": "background"; "required": false; }; "color": { "alias": "color"; "required": false; }; "line": { "alias": "line"; "required": false; }; "majorGridLines": { "alias": "majorGridLines"; "required": false; }; "majorTicks": { "alias": "majorTicks"; "required": false; }; "majorUnit": { "alias": "majorUnit"; "required": false; }; "max": { "alias": "max"; "required": false; }; "min": { "alias": "min"; "required": false; }; "minorGridLines": { "alias": "minorGridLines"; "required": false; }; "minorTicks": { "alias": "minorTicks"; "required": false; }; "minorUnit": { "alias": "minorUnit"; "required": false; }; "name": { "alias": "name"; "required": false; }; "narrowRange": { "alias": "narrowRange"; "required": false; }; "pane": { "alias": "pane"; "required": false; }; "plotBands": { "alias": "plotBands"; "required": false; }; "reverse": { "alias": "reverse"; "required": false; }; "type": { "alias": "type"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "crosshair": { "alias": "crosshair"; "required": false; }; "labels": { "alias": "labels"; "required": false; }; "notes": { "alias": "notes"; "required": false; }; "title": { "alias": "title"; "required": false; }; }, {}, never, never, true, never>;
}
