/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { AxisLabelContentArgs, AxisLabelVisualArgs, Border, LabelRotation, Margin } from '../../common/property-types';
import { AxisLabelsPosition } from '../../common/property-types';
import { Padding } from '../../common/property-types';
import { ValueAxisLabels } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The axis labels configuration.
 */
export declare class ValueAxisLabelsComponent extends SettingsComponent implements ValueAxisLabels {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    content: (e: AxisLabelContentArgs) => string;
    /**
     * The font style of the labels.
     * @default '12px sans-serif'
     */
    font: string;
    /**
     * The format for displaying the labels. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of IntlService.
     * Contains one placeholder (`"{0}"`) which represents the category value.
     * @default '{0}'
     */
    format: string;
    /**
     * The margin of the labels. A numeric value sets all margins.
     * @default 0
     */
    margin: Margin | number;
    mirror: boolean;
    /**
     * The padding of the labels. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    /**
     * The position of the axis labels. By default, labels are positioned next to the axis.
     * When `position` is set to `end`, the labels are placed at the end of the crossing axis, usually at the top or right end of the Chart unless the crossing axis has been reversed.
     * Alternatively, when the `position` property is set to `start`, the axis labels will be positioned at the beginning of the crossing axis, typically located at the left or bottom end of the Chart, unless the crossing axis has been reversed.
     * @default 'onAxis'
     */
    position: AxisLabelsPosition;
    /**
     * The rotation angle (in degrees) of the labels. By default, the labels are not rotated. Angles
     * increase clockwise and zero is to the left. Negative values are acceptable. Can be set to `"auto"` if
     * the axis is horizontal. In this case, the labels will be rotated only if the slot size is not
     * sufficient for the entire labels.
     * @default 0
     */
    rotation: LabelRotation | number | 'auto';
    /**
     * The number of labels to skip. By default, no labels are skipped.
     * @default 0
     */
    skip: number;
    /**
     * The label rendering step.
     * Every n<sup>th</sup> label is rendered where `n` is the step.
     * @default 1
     */
    step: number;
    /**
     * If set to `true`, the Chart displays the value axis labels.
     * @default true
     */
    visible: boolean;
    visual: (e: AxisLabelVisualArgs) => drawing.Element;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<ValueAxisLabelsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ValueAxisLabelsComponent, "kendo-chart-value-axis-item-labels", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "content": { "alias": "content"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "mirror": { "alias": "mirror"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "position": { "alias": "position"; "required": false; }; "rotation": { "alias": "rotation"; "required": false; }; "skip": { "alias": "skip"; "required": false; }; "step": { "alias": "step"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; }, {}, never, never, true, never>;
}
