/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { AxisTitlePosition, Border, Margin, Padding, TitleVisualArgs } from '../../common/property-types';
import { ValueAxisTitle } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The title configuration of the value axis.
 */
export declare class ValueAxisTitleComponent extends SettingsComponent implements ValueAxisTitle {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    /**
     * The font style of the title.
     * @default '16px sans-serif'
     */
    font: string;
    /**
     * The margin of the title. A numeric value sets all margins.
     * @default 5
     */
    margin: Margin | number;
    /**
     * The padding of the title. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    /**
     * The position of the title.
     * @default 'center'
     */
    position: AxisTitlePosition;
    /**
     * The rotation angle of the title. By default, the title is not rotated.
     * @default 0
     */
    rotation: number;
    text: string;
    /**
     * If set to `true`, the Chart displays the value axis title.
     * @default true
     */
    visible: boolean;
    visual: (e: TitleVisualArgs) => drawing.Element;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<ValueAxisTitleComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ValueAxisTitleComponent, "kendo-chart-value-axis-item-title", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "font": { "alias": "font"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "position": { "alias": "position"; "required": false; }; "rotation": { "alias": "rotation"; "required": false; }; "text": { "alias": "text"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; }, {}, never, never, true, never>;
}
