/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../../common/configuration.service';
import { Border, Padding } from '../../common/property-types';
import { XAxisCrosshairTooltip } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The configuration options of the crosshair tooltip.
 * The crosshair tooltip is displayed when the `visible` option is set to `true`.
 */
export declare class XAxisCrosshairTooltipComponent extends SettingsComponent implements XAxisCrosshairTooltip {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    /**
     * The font of the tooltip.
     * @default '12px sans-serif'
     */
    font: string;
    /**
     * The format for displaying the tooltip. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of `IntlService`.
     * Contains one placeholder (`"{0}"`) which represents the value.
     * @default '{0}'
     */
    format: string;
    /**
     * The padding of the crosshair tooltip. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    /**
     * If set to `true`, the Chart displays the crosshair tooltip of the Scatter chart X axis.
     * By default, the crosshair tooltip of the Scatter chart X axis is not visible.
     * @default false
     */
    visible: boolean;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<XAxisCrosshairTooltipComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<XAxisCrosshairTooltipComponent, "kendo-chart-x-axis-item-crosshair-tooltip", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; }, {}, never, never, true, never>;
}
