/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { AxisLabelContentArgs, AxisLabelsPosition, AxisLabelVisualArgs, Border, DateFormats, LabelRotation } from '../../common/property-types';
import { Margin, Padding } from '../../common/property-types';
import { XAxisLabels } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The axis labels configuration.
 */
export declare class XAxisLabelsComponent extends SettingsComponent implements XAxisLabels {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    content: (e: AxisLabelContentArgs) => string;
    culture: string;
    dateFormats: DateFormats;
    /**
     * The font style of the labels.
     * @default '12px sans-serif'
     */
    font: string;
    format: string;
    margin: Margin | number;
    mirror: boolean;
    /**
     * The padding of the labels. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    /**
     * The position of the axis labels. By default, labels are positioned next to the axis.
     * @default 'onAxis'
     */
    position: AxisLabelsPosition;
    /**
     * The rotation angle of the labels. By default, the labels are not rotated. Can be set to `"auto"`.
     * In this case, the labels are rotated only if the slot size is not sufficient for the entire labels.
     * @default 0
     */
    rotation: LabelRotation | number | 'auto';
    /**
     * The number of labels to skip.
     * @default 1
     */
    skip: number;
    /**
     * The label rendering step&mdash;renders every n<sup>th</sup> label. By default, every label is rendered.
     * @default 1
     */
    step: number;
    /**
     * If set to `true`, the Chart displays the X-axis labels. By default, the X-axis labels are visible.
     * @default true
     */
    visible: boolean;
    visual: (e: AxisLabelVisualArgs) => drawing.Element;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<XAxisLabelsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<XAxisLabelsComponent, "kendo-chart-x-axis-item-labels", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "content": { "alias": "content"; "required": false; }; "culture": { "alias": "culture"; "required": false; }; "dateFormats": { "alias": "dateFormats"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "mirror": { "alias": "mirror"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "position": { "alias": "position"; "required": false; }; "rotation": { "alias": "rotation"; "required": false; }; "skip": { "alias": "skip"; "required": false; }; "step": { "alias": "step"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; }, {}, never, never, true, never>;
}
