/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { ConfigurationService } from '../../common/configuration.service';
import { AxisLabelContentArgs, AxisLabelVisualArgs, Border, DateFormats, LabelRotation } from '../../common/property-types';
import { AxisLabelsPosition } from '../../common/property-types';
import { Margin, Padding } from '../../common/property-types';
import { YAxisLabels } from '../../common/property-types';
import { SettingsComponent } from '../../common/settings.component';
import * as i0 from "@angular/core";
/**
 * The axis labels configuration.
 */
export declare class YAxisLabelsComponent extends SettingsComponent implements YAxisLabels {
    configurationService: ConfigurationService;
    background: string;
    border: Border;
    color: string;
    content: (e: AxisLabelContentArgs) => string;
    culture: string;
    dateFormats: DateFormats;
    /**
     * The font style of the labels.
     * @default '12px sans-serif'
     */
    font: string;
    /**
     * The format for displaying the labels. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of `IntlService`.
     * Contains one placeholder (`"{0}"`) which represents the category value.
     * @default '{0}'
     */
    format: string;
    /**
     * The margin of the labels. A numeric value sets all margins.
     * @default 0
     */
    margin: Margin | number;
    /**
     * If set to `true`, the Chart mirrors the axis labels and ticks. If the labels are normally on the
     * left side of the axis, the mirroring of the axis renders them to the right.
     * @default false
     */
    mirror: boolean;
    /**
     * The padding of the labels. A numeric value sets all paddings.
     * @default 0
     */
    padding: Padding | number;
    /**
     * The position of the axis labels. By default, labels are positioned next to the axis.
     * @default 'onAxis'
     */
    position: AxisLabelsPosition;
    /**
     * The rotation angle of the labels. By default, the labels are not rotated.
     * @default 0
     */
    rotation: LabelRotation | number | 'auto';
    /**
     * The number of labels to skip.
     * @default 0
     */
    skip: number;
    /**
     * The label rendering step&mdash;renders every `n`<sup>th</sup> label. By default, every label is rendered.
     * @default 1
     */
    step: number;
    /**
     * If set to `true`, the Chart displays the Y-axis labels. By default, the Y-axis labels are visible.
     * @default true
     */
    visible: boolean;
    visual: (e: AxisLabelVisualArgs) => drawing.Element;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<YAxisLabelsComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<YAxisLabelsComponent, "kendo-chart-y-axis-item-labels", never, { "background": { "alias": "background"; "required": false; }; "border": { "alias": "border"; "required": false; }; "color": { "alias": "color"; "required": false; }; "content": { "alias": "content"; "required": false; }; "culture": { "alias": "culture"; "required": false; }; "dateFormats": { "alias": "dateFormats"; "required": false; }; "font": { "alias": "font"; "required": false; }; "format": { "alias": "format"; "required": false; }; "margin": { "alias": "margin"; "required": false; }; "mirror": { "alias": "mirror"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "position": { "alias": "position"; "required": false; }; "rotation": { "alias": "rotation"; "required": false; }; "skip": { "alias": "skip"; "required": false; }; "step": { "alias": "step"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "visual": { "alias": "visual"; "required": false; }; }, {}, never, never, true, never>;
}
