/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../common/configuration.service';
import { SettingsComponent } from '../common/settings.component';
import { DragAction, MousewheelZoom } from '../common/property-types';
import { Zoomable } from '../common/property-types';
import * as i0 from "@angular/core";
/**
 * Specifies if the Chart can be zoomed.
 * Zooming is not available for the `Donut`, `Pie`, `Funnel`, `Pyramid`, `Polar`, and `Radar` series.
 *
 * @example
 *
 * ```html-no-run
 * <kendo-chart>
 *   <kendo-chart-zoomable [mousewheel]="false"></kendo-chart-zoomable>
 * </kendo-chart>
 * ```
 */
export declare class ZoomableComponent extends SettingsComponent implements Zoomable {
    configurationService: ConfigurationService;
    mousewheel: boolean | MousewheelZoom;
    selection: boolean | DragAction;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<ZoomableComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<ZoomableComponent, "kendo-chart-zoomable", never, { "mousewheel": { "alias": "mousewheel"; "required": false; }; "selection": { "alias": "selection"; "required": false; }; }, {}, never, never, true, never>;
}
