/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SparklineComponent } from './sparkline.component';
import { ChartComponent } from './chart.component';
import { DonutCenterTemplateDirective } from './chart/donut-center-template.directive';
import { NoDataTemplateDirective } from './chart.directives';
import { XAxisComponent } from './chart/x-axis.component';
import { XAxisCrosshairComponent } from './chart/x-axis-item/crosshair.component';
import { XAxisCrosshairTooltipComponent } from './chart/x-axis-item/crosshair.tooltip.component';
import { XAxisItemComponent } from './chart/x-axis-item.component';
import { XAxisLabelsComponent } from './chart/x-axis-item/labels.component';
import { XAxisNotesComponent } from './chart/x-axis-item/notes.component';
import { XAxisNotesIconComponent } from './chart/x-axis-item/notes.icon.component';
import { XAxisNotesLabelComponent } from './chart/x-axis-item/notes.label.component';
import { XAxisTitleComponent } from './chart/x-axis-item/title.component';
import { YAxisComponent } from './chart/y-axis.component';
import { YAxisCrosshairComponent } from './chart/y-axis-item/crosshair.component';
import { YAxisCrosshairTooltipComponent } from './chart/y-axis-item/crosshair.tooltip.component';
import { YAxisItemComponent } from './chart/y-axis-item.component';
import { YAxisLabelsComponent } from './chart/y-axis-item/labels.component';
import { YAxisNotesComponent } from './chart/y-axis-item/notes.component';
import { YAxisNotesIconComponent } from './chart/y-axis-item/notes.icon.component';
import { YAxisNotesLabelComponent } from './chart/y-axis-item/notes.label.component';
import { YAxisTitleComponent } from './chart/y-axis-item/title.component';
import { ZoomableComponent } from './chart/zoomable.component';
import { SeriesTooltipTemplateDirective } from './chart/tooltip/series-tooltip-template.directive';
import { SharedTooltipTemplateDirective } from './chart/tooltip/shared-tooltip-template.directive';
import { CrosshairTooltipComponent } from './chart/tooltip/crosshair-tooltip.component';
import { CrosshairTooltipsContainerComponent } from './chart/tooltip/crosshair-tooltips-container.component';
import { TooltipPopupComponent } from './chart/tooltip/tooltip-popup.component';
import { AxisDefaultsComponent } from './chart/axis-defaults.component';
import { AxisDefaultsCrosshairComponent } from './chart/axis-defaults/crosshair.component';
import { AxisDefaultsCrosshairTooltipComponent } from './chart/axis-defaults/crosshair.tooltip.component';
import { AxisDefaultsLabelsComponent } from './chart/axis-defaults/labels.component';
import { AxisDefaultsTitleComponent } from './chart/axis-defaults/title.component';
import { CategoryAxisComponent } from './chart/category-axis.component';
import { CategoryAxisCrosshairComponent } from './chart/category-axis-item/crosshair.component';
import { CategoryAxisCrosshairTooltipComponent } from './chart/category-axis-item/crosshair.tooltip.component';
import { CategoryAxisItemComponent } from './chart/category-axis-item.component';
import { CategoryAxisLabelsComponent } from './chart/category-axis-item/labels.component';
import { CategoryAxisRangeLabelsComponent } from './chart/category-axis-item/range-labels.component';
import { CategoryAxisNotesComponent } from './chart/category-axis-item/notes.component';
import { CategoryAxisNotesIconComponent } from './chart/category-axis-item/notes.icon.component';
import { CategoryAxisNotesLabelComponent } from './chart/category-axis-item/notes.label.component';
import { CategoryAxisSelectComponent } from './chart/category-axis-item/select.component';
import { CategoryAxisTitleComponent } from './chart/category-axis-item/title.component';
import { ChartAreaComponent } from './chart/chart-area.component';
import { LegendComponent } from './chart/legend.component';
import { LegendInactiveItemsComponent } from './chart/legend/inactive-items.component';
import { LegendItemComponent } from './chart/legend/item.component';
import { PaneComponent } from './chart/pane.component';
import { PaneDefaultsComponent } from './chart/pane-defaults.component';
import { PaneDefaultsTitleComponent } from './chart/pane-defaults/title.component';
import { PanesComponent } from './chart/panes.component';
import { PanesTitleComponent } from './chart/pane/title.component';
import { PlotAreaComponent } from './chart/plot-area.component';
import { SeriesComponent } from './chart/series.component';
import { SeriesDefaultsComponent } from './chart/series-defaults.component';
import { SeriesDefaultsLabelsComponent } from './chart/series-defaults/labels.component';
import { SeriesDefaultsLabelsFromComponent } from './chart/series-defaults/labels.from.component';
import { SeriesDefaultsLabelsToComponent } from './chart/series-defaults/labels.to.component';
import { SeriesDefaultsNotesComponent } from './chart/series-defaults/notes.component';
import { SeriesDefaultsNotesIconComponent } from './chart/series-defaults/notes.icon.component';
import { SeriesDefaultsNotesLabelComponent } from './chart/series-defaults/notes.label.component';
import { SeriesDefaultsTooltipComponent } from './chart/series-defaults/tooltip.component';
import { SeriesErrorBarsComponent } from './chart/series-item/error-bars.component';
import { SeriesExtremesComponent } from './chart/series-item/extremes.component';
import { SeriesHighlightComponent } from './chart/series-item/highlight.component';
import { SeriesItemComponent } from './chart/series-item.component';
import { SeriesLabelsComponent } from './chart/series-item/labels.component';
import { SeriesLabelsFromComponent } from './chart/series-item/labels.from.component';
import { SeriesLabelsToComponent } from './chart/series-item/labels.to.component';
import { SeriesMarkersComponent } from './chart/series-item/markers.component';
import { SeriesNotesComponent } from './chart/series-item/notes.component';
import { SeriesNotesIconComponent } from './chart/series-item/notes.icon.component';
import { SeriesNotesLabelComponent } from './chart/series-item/notes.label.component';
import { SeriesOutliersComponent } from './chart/series-item/outliers.component';
import { SeriesTooltipComponent } from './chart/series-item/tooltip.component';
import { SeriesTrendlineComponent } from './chart/series-item/trendline.component';
import { SeriesTrendlineForecastComponent } from './chart/series-item/trendline.forecast.component';
import { SubtitleComponent } from './chart/subtitle.component';
import { TitleComponent } from './chart/title.component';
import { TooltipComponent } from './chart/tooltip.component';
import { ValueAxisComponent } from './chart/value-axis.component';
import { ValueAxisCrosshairComponent } from './chart/value-axis-item/crosshair.component';
import { ValueAxisCrosshairTooltipComponent } from './chart/value-axis-item/crosshair.tooltip.component';
import { ValueAxisItemComponent } from './chart/value-axis-item.component';
import { ValueAxisLabelsComponent } from './chart/value-axis-item/labels.component';
import { ValueAxisNotesComponent } from './chart/value-axis-item/notes.component';
import { ValueAxisNotesIconComponent } from './chart/value-axis-item/notes.icon.component';
import { ValueAxisNotesLabelComponent } from './chart/value-axis-item/notes.label.component';
import { ValueAxisTitleComponent } from './chart/value-axis-item/title.component';
import { SeriesDrilldownTemplateDirective } from './chart/series-drilldown-template.directive';
import { ChartBreadcrumbComponent } from './chart-breadcrumb.component';
import { ChartCustomMessagesComponent } from './chart/localization/custom-messages.component';
import { LocalizedChartMessagesDirective } from './chart/localization/localized-messages.directive';
import { StockChartComponent } from './stock-chart.component';
import { NavigatorComponent } from './stock-chart/navigator.component';
import { NavigatorCategoryAxisComponent } from './stock-chart/navigator/category-axis.component';
import { NavigatorCategoryAxisCrosshairComponent } from './stock-chart/navigator/category-axis/crosshair.component';
import { NavigatorCategoryAxisCrosshairTooltipComponent } from './stock-chart/navigator/category-axis/crosshair.tooltip.component';
import { NavigatorCategoryAxisLabelsComponent } from './stock-chart/navigator/category-axis/labels.component';
import { NavigatorCategoryAxisNotesComponent } from './stock-chart/navigator/category-axis/notes.component';
import { NavigatorCategoryAxisNotesIconComponent } from './stock-chart/navigator/category-axis/notes.icon.component';
import { NavigatorCategoryAxisNotesLabelComponent } from './stock-chart/navigator/category-axis/notes.label.component';
import { NavigatorCategoryAxisSelectComponent } from './stock-chart/navigator/category-axis/select.component';
import { NavigatorCategoryAxisTitleComponent } from './stock-chart/navigator/category-axis/title.component';
import { NavigatorHintComponent } from './stock-chart/navigator/hint.component';
import { NavigatorPaneComponent } from './stock-chart/navigator/pane.component';
import { NavigatorPaneTitleComponent } from './stock-chart/navigator/pane/title.component';
import { NavigatorSelectComponent } from './stock-chart/navigator/select.component';
import { NavigatorSeriesComponent } from './stock-chart/navigator/series.component';
import { NavigatorSeriesItemComponent } from './stock-chart/navigator/series-item.component';
import { NavigatorSeriesErrorBarsComponent } from './stock-chart/navigator/series-item/error-bars.component';
import { NavigatorSeriesExtremesComponent } from './stock-chart/navigator/series-item/extremes.component';
import { NavigatorSeriesHighlightComponent } from './stock-chart/navigator/series-item/highlight.component';
import { NavigatorSeriesLabelsComponent } from './stock-chart/navigator/series-item/labels.component';
import { NavigatorSeriesLabelsFromComponent } from './stock-chart/navigator/series-item/labels.from.component';
import { NavigatorSeriesLabelsToComponent } from './stock-chart/navigator/series-item/labels.to.component';
import { NavigatorSeriesMarkersComponent } from './stock-chart/navigator/series-item/markers.component';
import { NavigatorSeriesNotesComponent } from './stock-chart/navigator/series-item/notes.component';
import { NavigatorSeriesNotesIconComponent } from './stock-chart/navigator/series-item/notes.icon.component';
import { NavigatorSeriesNotesLabelComponent } from './stock-chart/navigator/series-item/notes.label.component';
import { NavigatorSeriesOutliersComponent } from './stock-chart/navigator/series-item/outliers.component';
import { NavigatorSeriesTooltipComponent } from './stock-chart/navigator/series-item/tooltip.component';
import { SankeyComponent } from './sankey.component';
import { SankeyFlatBindingDirective } from './sankey/data-binding/flat-binding.directive';
import { SankeyLabelsComponent } from './sankey/labels.component';
import { SankeyLegendComponent } from './sankey/legend.component';
import { SankeyLinksComponent } from './sankey/links.component';
import { SankeyCustomMessagesComponent } from './sankey/localization/custom-messages.component';
import { LocalizedMessagesDirective } from './sankey/localization/localized-messages.directive';
import { SankeyNodesComponent } from './sankey/nodes.component';
import { SankeyTitleComponent } from './sankey/title.component';
import { SankeyTooltipComponent } from './sankey/tooltip.component';
import { SankeyLinkTooltipTemplateDirective } from './sankey/tooltip/link-tooltip-template.directive';
import { SankeyNodeTooltipTemplateDirective } from './sankey/tooltip/node-tooltip-template.directive';
import { SankeyTooltipPopupComponent } from './sankey/tooltip/tooltip-popup.component';
/**
 * Utility array that contains all `Chart` related components and directives
 */
export declare const KENDO_CHART: readonly [typeof ChartComponent, typeof DonutCenterTemplateDirective, typeof NoDataTemplateDirective, typeof XAxisComponent, typeof XAxisCrosshairComponent, typeof XAxisCrosshairTooltipComponent, typeof XAxisItemComponent, typeof XAxisLabelsComponent, typeof XAxisNotesComponent, typeof XAxisNotesIconComponent, typeof XAxisNotesLabelComponent, typeof XAxisTitleComponent, typeof YAxisComponent, typeof YAxisCrosshairComponent, typeof YAxisCrosshairTooltipComponent, typeof YAxisItemComponent, typeof YAxisLabelsComponent, typeof YAxisNotesComponent, typeof YAxisNotesIconComponent, typeof YAxisNotesLabelComponent, typeof YAxisTitleComponent, typeof ZoomableComponent, typeof TooltipPopupComponent, typeof SeriesTooltipTemplateDirective, typeof SharedTooltipTemplateDirective, typeof CrosshairTooltipsContainerComponent, typeof CrosshairTooltipComponent, typeof AxisDefaultsComponent, typeof AxisDefaultsCrosshairComponent, typeof AxisDefaultsCrosshairTooltipComponent, typeof AxisDefaultsLabelsComponent, typeof AxisDefaultsTitleComponent, typeof CategoryAxisComponent, typeof CategoryAxisCrosshairComponent, typeof CategoryAxisCrosshairTooltipComponent, typeof CategoryAxisItemComponent, typeof CategoryAxisLabelsComponent, typeof CategoryAxisRangeLabelsComponent, typeof CategoryAxisNotesComponent, typeof CategoryAxisNotesIconComponent, typeof CategoryAxisNotesLabelComponent, typeof CategoryAxisSelectComponent, typeof CategoryAxisTitleComponent, typeof ChartAreaComponent, typeof ChartBreadcrumbComponent, typeof ChartCustomMessagesComponent, typeof LocalizedChartMessagesDirective, typeof LegendComponent, typeof LegendInactiveItemsComponent, typeof LegendItemComponent, typeof PaneComponent, typeof PaneDefaultsComponent, typeof PaneDefaultsTitleComponent, typeof PanesComponent, typeof PanesTitleComponent, typeof PlotAreaComponent, typeof SeriesComponent, typeof SeriesDefaultsComponent, typeof SeriesDefaultsLabelsComponent, typeof SeriesDefaultsLabelsFromComponent, typeof SeriesDefaultsLabelsToComponent, typeof SeriesDefaultsNotesComponent, typeof SeriesDefaultsNotesIconComponent, typeof SeriesDefaultsNotesLabelComponent, typeof SeriesDefaultsTooltipComponent, typeof SeriesDrilldownTemplateDirective, typeof SeriesErrorBarsComponent, typeof SeriesExtremesComponent, typeof SeriesHighlightComponent, typeof SeriesItemComponent, typeof SeriesLabelsComponent, typeof SeriesLabelsFromComponent, typeof SeriesLabelsToComponent, typeof SeriesMarkersComponent, typeof SeriesNotesComponent, typeof SeriesNotesIconComponent, typeof SeriesNotesLabelComponent, typeof SeriesOutliersComponent, typeof SeriesTooltipComponent, typeof SeriesTrendlineComponent, typeof SeriesTrendlineForecastComponent, typeof SubtitleComponent, typeof TitleComponent, typeof TooltipComponent, typeof ValueAxisComponent, typeof ValueAxisCrosshairComponent, typeof ValueAxisCrosshairTooltipComponent, typeof ValueAxisItemComponent, typeof ValueAxisLabelsComponent, typeof ValueAxisNotesComponent, typeof ValueAxisNotesIconComponent, typeof ValueAxisNotesLabelComponent, typeof ValueAxisTitleComponent];
/**
 * Utility array that contains all `SparkLine` related components and directives
 */
export declare const KENDO_SPARKLINE: readonly [typeof SparklineComponent];
/**
 * Utility array that contains all `StockChart` related components and directives
 */
export declare const KENDO_STOCKCHART: readonly [typeof StockChartComponent, typeof NavigatorComponent, typeof NavigatorCategoryAxisComponent, typeof NavigatorCategoryAxisCrosshairComponent, typeof NavigatorCategoryAxisCrosshairTooltipComponent, typeof NavigatorCategoryAxisLabelsComponent, typeof NavigatorCategoryAxisNotesComponent, typeof NavigatorCategoryAxisNotesIconComponent, typeof NavigatorCategoryAxisNotesLabelComponent, typeof NavigatorCategoryAxisSelectComponent, typeof NavigatorCategoryAxisTitleComponent, typeof NavigatorHintComponent, typeof NavigatorPaneComponent, typeof NavigatorPaneTitleComponent, typeof NavigatorSelectComponent, typeof NavigatorSeriesComponent, typeof NavigatorSeriesItemComponent, typeof NavigatorSeriesErrorBarsComponent, typeof NavigatorSeriesExtremesComponent, typeof NavigatorSeriesHighlightComponent, typeof NavigatorSeriesLabelsComponent, typeof NavigatorSeriesLabelsFromComponent, typeof NavigatorSeriesLabelsToComponent, typeof NavigatorSeriesMarkersComponent, typeof NavigatorSeriesNotesComponent, typeof NavigatorSeriesNotesIconComponent, typeof NavigatorSeriesNotesLabelComponent, typeof NavigatorSeriesOutliersComponent, typeof NavigatorSeriesTooltipComponent, typeof TooltipPopupComponent, typeof SeriesTooltipTemplateDirective, typeof SharedTooltipTemplateDirective, typeof CrosshairTooltipsContainerComponent, typeof CrosshairTooltipComponent, typeof AxisDefaultsComponent, typeof AxisDefaultsCrosshairComponent, typeof AxisDefaultsCrosshairTooltipComponent, typeof AxisDefaultsLabelsComponent, typeof AxisDefaultsTitleComponent, typeof CategoryAxisComponent, typeof CategoryAxisCrosshairComponent, typeof CategoryAxisCrosshairTooltipComponent, typeof CategoryAxisItemComponent, typeof CategoryAxisLabelsComponent, typeof CategoryAxisRangeLabelsComponent, typeof CategoryAxisNotesComponent, typeof CategoryAxisNotesIconComponent, typeof CategoryAxisNotesLabelComponent, typeof CategoryAxisSelectComponent, typeof CategoryAxisTitleComponent, typeof ChartAreaComponent, typeof ChartBreadcrumbComponent, typeof LegendComponent, typeof LegendInactiveItemsComponent, typeof LegendItemComponent, typeof PaneComponent, typeof PaneDefaultsComponent, typeof PaneDefaultsTitleComponent, typeof PanesComponent, typeof PanesTitleComponent, typeof PlotAreaComponent, typeof SeriesComponent, typeof SeriesDefaultsComponent, typeof SeriesDefaultsLabelsComponent, typeof SeriesDefaultsLabelsFromComponent, typeof SeriesDefaultsLabelsToComponent, typeof SeriesDefaultsNotesComponent, typeof SeriesDefaultsNotesIconComponent, typeof SeriesDefaultsNotesLabelComponent, typeof SeriesDefaultsTooltipComponent, typeof SeriesDrilldownTemplateDirective, typeof SeriesErrorBarsComponent, typeof SeriesExtremesComponent, typeof SeriesHighlightComponent, typeof SeriesItemComponent, typeof SeriesLabelsComponent, typeof SeriesLabelsFromComponent, typeof SeriesLabelsToComponent, typeof SeriesMarkersComponent, typeof SeriesNotesComponent, typeof SeriesNotesIconComponent, typeof SeriesNotesLabelComponent, typeof SeriesOutliersComponent, typeof SeriesTooltipComponent, typeof SeriesTrendlineComponent, typeof SeriesTrendlineForecastComponent, typeof SubtitleComponent, typeof TitleComponent, typeof TooltipComponent, typeof ValueAxisComponent, typeof ValueAxisCrosshairComponent, typeof ValueAxisCrosshairTooltipComponent, typeof ValueAxisItemComponent, typeof ValueAxisLabelsComponent, typeof ValueAxisNotesComponent, typeof ValueAxisNotesIconComponent, typeof ValueAxisNotesLabelComponent, typeof ValueAxisTitleComponent];
/**
 * Utility array that contains all `Sankey` related components and directives
 */
export declare const KENDO_SANKEY: readonly [typeof SankeyComponent, typeof SankeyTooltipPopupComponent, typeof SankeyLinkTooltipTemplateDirective, typeof SankeyNodeTooltipTemplateDirective, typeof SankeyCustomMessagesComponent, typeof LocalizedMessagesDirective, typeof SankeyTitleComponent, typeof SankeyLegendComponent, typeof SankeyTooltipComponent, typeof SankeyLinksComponent, typeof SankeyNodesComponent, typeof SankeyLabelsComponent, typeof SankeyFlatBindingDirective];
/**
 * Utility array that contains all `@progress/kendo-angular-charts` related components and directives
 */
export declare const KENDO_CHARTS: readonly [typeof ChartComponent, typeof DonutCenterTemplateDirective, typeof NoDataTemplateDirective, typeof XAxisComponent, typeof XAxisCrosshairComponent, typeof XAxisCrosshairTooltipComponent, typeof XAxisItemComponent, typeof XAxisLabelsComponent, typeof XAxisNotesComponent, typeof XAxisNotesIconComponent, typeof XAxisNotesLabelComponent, typeof XAxisTitleComponent, typeof YAxisComponent, typeof YAxisCrosshairComponent, typeof YAxisCrosshairTooltipComponent, typeof YAxisItemComponent, typeof YAxisLabelsComponent, typeof YAxisNotesComponent, typeof YAxisNotesIconComponent, typeof YAxisNotesLabelComponent, typeof YAxisTitleComponent, typeof ZoomableComponent, typeof TooltipPopupComponent, typeof SeriesTooltipTemplateDirective, typeof SharedTooltipTemplateDirective, typeof CrosshairTooltipsContainerComponent, typeof CrosshairTooltipComponent, typeof AxisDefaultsComponent, typeof AxisDefaultsCrosshairComponent, typeof AxisDefaultsCrosshairTooltipComponent, typeof AxisDefaultsLabelsComponent, typeof AxisDefaultsTitleComponent, typeof CategoryAxisComponent, typeof CategoryAxisCrosshairComponent, typeof CategoryAxisCrosshairTooltipComponent, typeof CategoryAxisItemComponent, typeof CategoryAxisLabelsComponent, typeof CategoryAxisRangeLabelsComponent, typeof CategoryAxisNotesComponent, typeof CategoryAxisNotesIconComponent, typeof CategoryAxisNotesLabelComponent, typeof CategoryAxisSelectComponent, typeof CategoryAxisTitleComponent, typeof ChartAreaComponent, typeof ChartBreadcrumbComponent, typeof ChartCustomMessagesComponent, typeof LocalizedChartMessagesDirective, typeof LegendComponent, typeof LegendInactiveItemsComponent, typeof LegendItemComponent, typeof PaneComponent, typeof PaneDefaultsComponent, typeof PaneDefaultsTitleComponent, typeof PanesComponent, typeof PanesTitleComponent, typeof PlotAreaComponent, typeof SeriesComponent, typeof SeriesDefaultsComponent, typeof SeriesDefaultsLabelsComponent, typeof SeriesDefaultsLabelsFromComponent, typeof SeriesDefaultsLabelsToComponent, typeof SeriesDefaultsNotesComponent, typeof SeriesDefaultsNotesIconComponent, typeof SeriesDefaultsNotesLabelComponent, typeof SeriesDefaultsTooltipComponent, typeof SeriesDrilldownTemplateDirective, typeof SeriesErrorBarsComponent, typeof SeriesExtremesComponent, typeof SeriesHighlightComponent, typeof SeriesItemComponent, typeof SeriesLabelsComponent, typeof SeriesLabelsFromComponent, typeof SeriesLabelsToComponent, typeof SeriesMarkersComponent, typeof SeriesNotesComponent, typeof SeriesNotesIconComponent, typeof SeriesNotesLabelComponent, typeof SeriesOutliersComponent, typeof SeriesTooltipComponent, typeof SeriesTrendlineComponent, typeof SeriesTrendlineForecastComponent, typeof SubtitleComponent, typeof TitleComponent, typeof TooltipComponent, typeof ValueAxisComponent, typeof ValueAxisCrosshairComponent, typeof ValueAxisCrosshairTooltipComponent, typeof ValueAxisItemComponent, typeof ValueAxisLabelsComponent, typeof ValueAxisNotesComponent, typeof ValueAxisNotesIconComponent, typeof ValueAxisNotesLabelComponent, typeof ValueAxisTitleComponent, typeof SparklineComponent, typeof StockChartComponent, typeof NavigatorComponent, typeof NavigatorCategoryAxisComponent, typeof NavigatorCategoryAxisCrosshairComponent, typeof NavigatorCategoryAxisCrosshairTooltipComponent, typeof NavigatorCategoryAxisLabelsComponent, typeof NavigatorCategoryAxisNotesComponent, typeof NavigatorCategoryAxisNotesIconComponent, typeof NavigatorCategoryAxisNotesLabelComponent, typeof NavigatorCategoryAxisSelectComponent, typeof NavigatorCategoryAxisTitleComponent, typeof NavigatorHintComponent, typeof NavigatorPaneComponent, typeof NavigatorPaneTitleComponent, typeof NavigatorSelectComponent, typeof NavigatorSeriesComponent, typeof NavigatorSeriesItemComponent, typeof NavigatorSeriesErrorBarsComponent, typeof NavigatorSeriesExtremesComponent, typeof NavigatorSeriesHighlightComponent, typeof NavigatorSeriesLabelsComponent, typeof NavigatorSeriesLabelsFromComponent, typeof NavigatorSeriesLabelsToComponent, typeof NavigatorSeriesMarkersComponent, typeof NavigatorSeriesNotesComponent, typeof NavigatorSeriesNotesIconComponent, typeof NavigatorSeriesNotesLabelComponent, typeof NavigatorSeriesOutliersComponent, typeof NavigatorSeriesTooltipComponent, typeof TooltipPopupComponent, typeof SeriesTooltipTemplateDirective, typeof SharedTooltipTemplateDirective, typeof CrosshairTooltipsContainerComponent, typeof CrosshairTooltipComponent, typeof AxisDefaultsComponent, typeof AxisDefaultsCrosshairComponent, typeof AxisDefaultsCrosshairTooltipComponent, typeof AxisDefaultsLabelsComponent, typeof AxisDefaultsTitleComponent, typeof CategoryAxisComponent, typeof CategoryAxisCrosshairComponent, typeof CategoryAxisCrosshairTooltipComponent, typeof CategoryAxisItemComponent, typeof CategoryAxisLabelsComponent, typeof CategoryAxisRangeLabelsComponent, typeof CategoryAxisNotesComponent, typeof CategoryAxisNotesIconComponent, typeof CategoryAxisNotesLabelComponent, typeof CategoryAxisSelectComponent, typeof CategoryAxisTitleComponent, typeof ChartAreaComponent, typeof ChartBreadcrumbComponent, typeof LegendComponent, typeof LegendInactiveItemsComponent, typeof LegendItemComponent, typeof PaneComponent, typeof PaneDefaultsComponent, typeof PaneDefaultsTitleComponent, typeof PanesComponent, typeof PanesTitleComponent, typeof PlotAreaComponent, typeof SeriesComponent, typeof SeriesDefaultsComponent, typeof SeriesDefaultsLabelsComponent, typeof SeriesDefaultsLabelsFromComponent, typeof SeriesDefaultsLabelsToComponent, typeof SeriesDefaultsNotesComponent, typeof SeriesDefaultsNotesIconComponent, typeof SeriesDefaultsNotesLabelComponent, typeof SeriesDefaultsTooltipComponent, typeof SeriesDrilldownTemplateDirective, typeof SeriesErrorBarsComponent, typeof SeriesExtremesComponent, typeof SeriesHighlightComponent, typeof SeriesItemComponent, typeof SeriesLabelsComponent, typeof SeriesLabelsFromComponent, typeof SeriesLabelsToComponent, typeof SeriesMarkersComponent, typeof SeriesNotesComponent, typeof SeriesNotesIconComponent, typeof SeriesNotesLabelComponent, typeof SeriesOutliersComponent, typeof SeriesTooltipComponent, typeof SeriesTrendlineComponent, typeof SeriesTrendlineForecastComponent, typeof SubtitleComponent, typeof TitleComponent, typeof TooltipComponent, typeof ValueAxisComponent, typeof ValueAxisCrosshairComponent, typeof ValueAxisCrosshairTooltipComponent, typeof ValueAxisItemComponent, typeof ValueAxisLabelsComponent, typeof ValueAxisNotesComponent, typeof ValueAxisNotesIconComponent, typeof ValueAxisNotesLabelComponent, typeof ValueAxisTitleComponent, typeof SankeyComponent, typeof SankeyTooltipPopupComponent, typeof SankeyLinkTooltipTemplateDirective, typeof SankeyNodeTooltipTemplateDirective, typeof SankeyCustomMessagesComponent, typeof LocalizedMessagesDirective, typeof SankeyTitleComponent, typeof SankeyLegendComponent, typeof SankeyTooltipComponent, typeof SankeyLinksComponent, typeof SankeyNodesComponent, typeof SankeyLabelsComponent, typeof SankeyFlatBindingDirective];
