/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The point that is passed to the tooltip template.
 */
export class TooltipTemplatePoint {
    /**
     * The point value.
     */
    value;
    /**
     * The point category. Available only for the Categorical series.
     */
    category;
    /**
     * The point category index. Available only for the Categorical series.
     */
    categoryIndex;
    /**
     * The point series options.
     */
    series;
    /**
     * The point `dataItem`.
     */
    dataItem;
    /**
     * The point value represented as a percentage value. Available only for the Donut, Pie, and 100% Stacked charts.
     */
    percentage;
    /**
     * The sum of point values since the last `"runningTotal"` summary point. Available for the Waterfall series.
     */
    runningTotal;
    /**
     * The sum of all previous series values. Available for the Waterfall series.
     */
    total;
    /**
     * The low value of the point error bar. Available for the Categorical series with error bars.
     */
    low;
    /**
     * The high value of the point error bar. Available for the Categorical series with error bars.
     */
    high;
    /**
     * The x low value of the point error bar. Available for the Scatter series with error bars.
     */
    xLow;
    /**
     * The x high value of the point error bar. Available for the Scatter series with error bars.
     */
    xHigh;
    /**
     * The y low value of the point error bar. Available for the Scatter series with error bars.
     */
    yLow;
    /**
     * The y low value of the point error bar. Available for the Scatter series with error bars.
     */
    yHigh;
    /**
     * @hidden
     */
    template;
    /**
     * @hidden
     */
    point;
    /**
     * @hidden
     */
    format;
    /**
     * @hidden
     */
    constructor(point, format, template) {
        this.value = point.value;
        this.category = point.category;
        this.categoryIndex = point.categoryIx;
        this.series = point.series;
        this.dataItem = point.dataItem;
        this.percentage = point.percentage;
        this.runningTotal = point.runningTotal;
        this.total = point.total;
        this.low = point.low;
        this.high = point.high;
        this.xLow = point.xLow;
        this.xHigh = point.xHigh;
        this.yLow = point.yLow;
        this.yHigh = point.yHigh;
        this.template = template;
        this.point = point;
        this.format = format;
    }
    /**
     * @hidden
     */
    get formattedValue() {
        return this.format ? this.point.formatValue(this.format) : String(this.value);
    }
}
