/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { BaseEvent } from './base-event';
/**
 * Arguments for the `seriesClick` event([see example](slug:events_chart)).
 */
export class SeriesClickEvent extends BaseEvent {
    /**
     * The data point category.
     */
    category;
    /**
     * The original data item.
     */
    dataItem;
    /**
     * The original user event that triggered the drag action.
     */
    originalEvent;
    /**
     * The point value represented as a percentage value.
     * Available only for the Donut, Pie, and 100% stacked charts.
     */
    percentage;
    /**
     * The clicked series point.
     */
    point;
    /**
     * The clicked point series options.
     */
    series;
    /**
     * The cumulative point value on the stack. Available only for the stackable series.
     */
    stackValue;
    /**
     * The data point value.
     */
    value;
    /**
     * @hidden
     */
    constructor(e, sender) {
        super(sender);
        this.category = e.category;
        this.dataItem = e.dataItem;
        this.originalEvent = e.originalEvent;
        this.percentage = e.percentage;
        this.point = e.point;
        this.series = e.series;
        this.stackValue = e.stackValue;
        this.value = e.value;
    }
}
