/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { PreventableEvent } from './preventable-event';
/**
 * Arguments for the `zoom` event ([see example](slug:panzoom_chart_charts#toc-pan-and-zoom-events)).
 */
export class ZoomEvent extends PreventableEvent {
    /**
     * A dictionary which contains the range (min and max values) of named axes.
     * The axis name is used as a key.
     *
     * > The dictionary includes only the affected axis ranges.
     * If an axis is locked or its range is not modified, the axis will not be listed.
     */
    axisRanges;
    /**
     * A number that indicates the zoom amount and direction.
     * A negative value indicates a zoom-in action.
     * A positive value indicates a zoom-out action.
     */
    delta;
    /**
     * The original user event that triggered the drag action.
     */
    originalEvent;
    /**
     * @hidden
     */
    constructor(e, sender) {
        super(sender);
        this.axisRanges = e.axisRanges;
        this.delta = e.delta;
        this.originalEvent = e.originalEvent;
    }
}
