/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The allowed time-interval steps when `baseUnit` is set to either `"fit"` or `"auto"`.
 *
 * The axis will divide the active period into the smallest possible intervals
 * that do not exceed the set `maxDateGroups` value.
 *
 *
 * ```html
 * <kendo-chart-category-axis>
 *  <kendo-chart-category-axis-item [autoBaseUnitSteps]="baseUnitSteps">
 *  </kendo-chart-category-axis-item>
 * </kendo-chart-category-axis>
 * ```
 * ```ts
 * public baseUnitSteps: AutoBaseUnitSteps = {
 *  // Do not allow zooming into hours
 *  weeks: [],
 * };
 * ```
 */
export interface AutoBaseUnitSteps {
    /**
     * The preferred interval steps when displaying milliseconds.
     */
    milliseconds?: number[];
    /**
     * The preferred interval steps when displaying seconds.
     */
    seconds?: number[];
    /**
     * The preferred interval steps when displaying minutes.
     */
    minutes?: number[];
    /**
     * The preferred interval steps when displaying hours.
     */
    hours?: number[];
    /**
     * The preferred interval steps when displaying days.
     */
    days?: number[];
    /**
     * The preferred interval steps when displaying weeks.
     */
    weeks?: number[];
    /**
     * The preferred interval steps when displaying months.
     */
    months?: number[];
    /**
     * The preferred interval steps when displaying years.
     */
    years?: number[];
}
