/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The position of the axis labels.
 *
 * The possible values are:
 * - `"start"`&mdash;The labels are positioned at the start of the axis.
 * - `"end"`&mdash;The labels are positioned at the end of the axis.
 * - `"onAxis"`&mdash;The labels are positioned on the axis.
 * - `""`&mdash;The labels are positioned based on the axis type.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { AxisLabelsPosition } from '@progress/kendo-angular-charts';
 *
 * _@Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-chart>
 *       <kendo-chart-category-axis>
 *         <kendo-chart-category-axis-item>
 *           <kendo-chart-category-axis-item-labels [position]="position">
 *           </kendo-chart-category-axis-item-labels>
 *         </kendo-chart-category-axis-item>
 *       </kendo-chart-category-axis>
 *     </kendo-chart>
 *   `
 * })
 * class AppComponent {
 *   public position: AxisLabelsPosition = "end";
 * }
 *
 * ```
 */
export type AxisLabelsPosition = 'start' | 'end' | 'onAxis' | '';
