/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { DashType } from './dash-type';
/**
 * The appearance settings for the axis lines.
 * Affects the major and minor axis ticks, but not the grid lines
 * ([see example](slug:axes_chart_charts#toc-default-axis-configuration)).
 */
export interface AxisLine {
    /**
     * The color of the lines. Accepts a valid CSS color string, including hex and rgb.
     * Setting the `color` option affects the major and minor axis ticks, but not the grid lines.
     */
    color?: string;
    /**
     * The dash type of the line.
     */
    dashType?: DashType;
    /**
     * If set to `true`, the Chart displays the axis lines.
     * By default, the axis lines are visible.
     */
    visible?: boolean;
    /**
     * The width of the line in pixels.
     * Affects the major and minor axis ticks, but not the grid lines.
     */
    width?: number;
}
