/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The position of an axis title.
 *
 * The possible values are:
 * - `"top"`&mdash;The title is positioned at the top of the axis.
 * - `"bottom"`&mdash;The title is positioned at the bottom of the axis.
 * - `"left"`&mdash;The title is positioned at the left of the axis.
 * - `"right"`&mdash;The title is positioned at the right of the axis.
 * - `"center"`&mdash;The title is positioned at the center of the axis.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { AxisTitlePosition } from '@progress/kendo-angular-charts';
 *
 * _@Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-chart>
 *       <kendo-chart-value-axis>
 *         <kendo-chart-value-axis-item>
 *           <kendo-chart-value-axis-item-title [position]="position" text="Title">
 *           </kendo-chart-value-axis-item-title>
 *         </kendo-chart-value-axis-item>
 *       </kendo-chart-value-axis>
 *     </kendo-chart>
 *   `
 * })
 * class AppComponent {
 *   public position: AxisTitlePosition = "top";
 * }
 *
 * ```
 */
export type AxisTitlePosition = 'top' | 'bottom' | 'left' | 'right' | 'center';
