/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The `baseUnit` type of a X or Y axis.
 *
 * The possible values are:
 * - `"milliseconds"`&mdash;The base unit is milliseconds.
 * - `"seconds"`&mdash;The base unit is seconds.
 * - `"minutes"`&mdash;The base unit is minutes.
 * - `"hours"`&mdash;The base unit is hours.
 * - `"days"`&mdash;The base unit is days.
 * - `"weeks"`&mdash;The base unit is weeks.
 * - `"months"`&mdash;The base unit is months.
 * - `"years"`&mdash;The base unit is years.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { BaseUnit } from '@progress/kendo-angular-charts';
 *
 * _@Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-chart>
 *       <kendo-chart-x-axis>
 *         <kendo-chart-x-axis-item [baseUnit]="baseUnit">
 *         </kendo-chart-x-axis-item>
 *       </kendo-chart-x-axis>
 *       <kendo-chart-series>
 *         <kendo-chart-series-item type="scatter" [data]="data">
 *         </kendo-chart-series-item>
 *       </kendo-chart-series>
 *     </kendo-chart>
 *   `
 * })
 * class AppComponent {
 *   public baseUnit: BaseUnit = "months";
 *   public data: any[] = [[new Date(2000, 0, 1), 1], [new Date(2001, 0, 1), 1]];
 * }
 *
 * ```
 */
export type BaseUnit = 'milliseconds' | 'seconds' | 'minutes' | 'hours' | 'days' | 'weeks' | 'months' | 'years';
