/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The dash line type.
 *
 * The possible values are:
 * - `"dash"`&mdash;A line that consists of dashes.
 * - `"dashDot"`&mdash;A line that consists of a repeating dash-dot pattern.
 * - `"dot"`&mdash;A line that consists of dots.
 * - `"longDash"`&mdash;A line that consists of a repeating long-dash pattern.
 * - `"longDashDot"`&mdash;A line that consists of a repeating long-dash-dot pattern.
 * - `"longDashDotDot"`&mdash;A line that consists of a repeating long-dash-dot-dot pattern.
 * - `"solid"`&mdash;A solid line.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { DashType } from '@progress/kendo-angular-charts';
 *
 * _@Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-chart>
 *       <kendo-chart-series>
 *         <kendo-chart-series-item type="line" [data]="[1, 2, 3]" [dashType]="dashType">
 *         </kendo-chart-series-item>
 *       </kendo-chart-series>
 *     </kendo-chart>
 *   `
 * })
 * class AppComponent {
 *   public dashType: DashType = "dot";
 * }
 *
 * ```
 */
export type DashType = 'dash' | 'dashDot' | 'dot' | 'longDash' | 'longDashDot' | 'longDashDotDot' | 'solid';
