/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * The line style of the series.
 *
 * The possible values are:
 * - `"normal"`&mdash;The values are connected with a straight line.
 * - `"step"`&mdash;The values are connected with a right-angled line. Available when [`series.type`]({% slug api_charts_series %}#toc-type) is set to `"line"`.
 * - `"smooth"`&mdash;The values are connected with a smooth line. Not supported for stacked area series with missing values.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { LineStyle } from '@progress/kendo-angular-charts';
 *
 * _@Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-chart>
 *       <kendo-chart-series>
 *         <kendo-chart-series-item type="line" [data]="[1, 2, 1]" [style]="style">
 *         </kendo-chart-series-item>
 *       </kendo-chart-series>
 *     </kendo-chart>
 *   `
 * })
 * export class AppComponent {
 *   public style: LineStyle = "smooth";
 * }
 *
 * ```
 */
export type LineStyle = 'normal' | 'step' | 'smooth';
