/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Specifies a modifier key.
 *
 * The possible values are:
 * - `"none"`&mdash;No modifier key is pressed.
 * - `"ctrl"`&mdash;The `Ctrl` key is pressed.
 * - `"shift"`&mdash;The `Shift` key is pressed.
 * - `"alt"`&mdash;The `Alt` key is pressed.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { DragAction } from '@progress/kendo-angular-charts';
 *
 * _@Component({
 *  selector: 'my-app',
 * template: `
 * <kendo-chart [zoomable]="true">
 *  <kendo-chart-zoomable [selection]="dragAction"></kendo-chart-zoomable>
 * </kendo-chart>
 * `
 * })
 * export class AppComponent {
 *  public dragAction: DragAction = { key: 'shift' };
 * }
 * ```
 */
export type ModifierKey = 'none' | 'ctrl' | 'shift' | 'alt';
