/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
/**
 * Specifies the position of a note.
 *
 * The possible values are:
 * - `"top"`&mdash;The note is positioned at the top of the axis.
 * - `"bottom"`&mdash;The note is positioned at the bottom of the axis.
 * - `"left"`&mdash;The note is positioned at the left of the axis.
 * - `"right"`&mdash;The note is positioned at the right of the axis.
 *
 * @example
 * ```ts
 * import { Component } from '@angular/core';
 * import { NotePosition } from '@progress/kendo-angular-charts';
 *
 * _@Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-chart>
 *       <kendo-chart-value-axis>
 *         <kendo-chart-value-axis-item>
 *           <kendo-chart-value-axis-item-notes [position]="position" [data]="[{ value: 1 }]">
 *           </kendo-chart-value-axis-item-notes>
 *         </kendo-chart-value-axis-item>
 *       </kendo-chart-value-axis>
 *     </kendo-chart>
 *   `
 * })
 * class AppComponent {
 *   public position: NotePosition = "right";
 * }
 *
 * ```
 */
export type NotePosition = 'top' | 'bottom' | 'left' | 'right';
