/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { PlotBandLabelVisualArgs } from '../common/property-types';
import { Border } from './border.interface';
import { Margin } from './margin.interface';
import { Padding } from './padding.interface';
/**
 * The appearance configuration for the plot band label.
 */
export interface PlotBandLabel {
    /**
     * The horizontal alignment of the label text.
     *
     * By default, the label is aligned to the left.
     *
     * The positioning of the label within a plot band can be set to `center` for center positioning, `right` for positioning on the right side, or `left` for positioning on the left side.
     */
    align?: 'center' | 'right' | 'left';
    /**
     * The background color of the label. Accepts a valid CSS color string, including hex and rgb.
     */
    background?: string;
    /**
     * The border of the label.
     */
    border?: Border;
    /**
     * The color of the plot band label text.
     * Accepts a valid [CSS `color`](https://developer.mozilla.org/en-US/docs/Web/CSS/color)
     * configuration string, including hex and rgb.
     */
    color?: string;
    /**
     * The font of the plot band label text.
     * Accepts a valid [CSS `font`](https://developer.mozilla.org/en-US/docs/Web/CSS/font)
     * configuration string.
     */
    font?: string;
    /**
     * The margin of the label. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The padding of the label. A numeric value sets all paddings.
     */
    padding?: Padding | number;
    /**
     * The vertical position of the label inside the plot band.
     *
     * By default, the label is aligned to the top.
     *
     * The positioning of the label within a plot band can be set to `bottom` for positioning at the bottom, `center` for center positioning, or `top` for positioning at the top.
     */
    position?: 'bottom' | 'center' | 'top';
    /**
     * The rotation angle of the label. By default, the label is not rotated.
     */
    rotation?: number;
    /**
     * The text of the label.
     *
     * The text can be split into multiple lines by using line feed characters ("\n").
     */
    text?: string;
    /**
     * If set to `false`, the will not display the plot band label.
     * By default, the plot band labels are not displayed.
     */
    visible?: boolean;
    /**
     * A function that can be used to create a custom visual for the label.
     */
    visual?: (e: PlotBandLabelVisualArgs) => drawing.Element;
}
