/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { AxisTitlePosition, Border, Margin, Padding, TitleVisualArgs } from '../../common/property-types';
/**
 * The configuration options for the axis title
 * ([see example](slug:axes_chart_charts#toc-default-axis-configuration)).
 */
export interface AxisDefaultsTitle {
    /**
     * The background color of the title. Accepts a valid CSS color string, including hex and rgb.
     */
    background?: string;
    /**
     * The border of the title.
     */
    border?: Border;
    /**
     * The text color of the title. Accepts a valid CSS color string, including hex and rgb.
     */
    color?: string;
    /**
     * The font style of the title.
     */
    font?: string;
    /**
     * The margin of the title. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The padding of the title. A numeric value sets all paddings.
     */
    padding?: Padding | number;
    /**
     * The position of the title.
     */
    position?: AxisTitlePosition;
    /**
     * The rotation angle of the title. By default, the title is not rotated.
     */
    rotation?: number;
    /**
     * The text of the title. The text can be split into multiple lines by using the line feed characters (`"\n"`).
     */
    text?: string;
    /**
     * If set to `true`, the Chart displays the axis title. By default, the axis title is visible.
     */
    visible?: boolean;
    /**
     * A function that can be used to create a custom visual for the title.
     */
    visual?: (e: TitleVisualArgs) => drawing.Element;
}
