/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { Border, Margin } from '../../common/property-types';
/**
 * The options for default pane title.
 */
export interface PaneDefaultsTitle {
    /**
     * The background color of the title. Accepts a valid CSS color string, including HEX and RGB.
     */
    background?: string;
    /**
     * The border of the title.
     */
    border?: Border;
    /**
     * The text color of the title. Accepts a valid CSS color string, including hex and rgb.
     */
    color?: string;
    /**
     * The font style of the title.
     */
    font?: string;
    /**
     * The margin of the title. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The position of the title.
     *
     * The positioning of the axis title can be set to `left` for left positioning, `right` for right positioning (both applicable to the horizontal axis), or `center` for positioning in the center.
     */
    position?: 'left' | 'right' | 'center';
    /**
     * If set to `true`, the Chart displays the pane title. By default, the pane title is visible.
     */
    visible?: boolean;
    /**
     * A function that can be used to create a custom visual for the title.
     */
    visual?: (e: any) => drawing.Element;
}
