/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Border, Margin, Padding, SeriesLabelsContentArgs } from '../../common/property-types';
/**
 * The configuration options of the Chart series `from` labels.
 */
export interface SeriesDefaultsLabelsFrom {
    /**
     * The background color of the `from` labels. Accepts a valid CSS color string, including HEX and RGB.
     */
    background?: string;
    /**
     * The border of the `from` labels.
     */
    border?: Border;
    /**
     * The text color of the `from` labels. Accepts a valid CSS color string, including HEX and RGB.
     */
    color?: string;
    /**
     * The function which returns the `from` label content of the Chart series.
     * You can split the text into multiple lines by using line feed characters (`"\n"`).
     */
    content?: (e: SeriesLabelsContentArgs) => string;
    /**
     * The font style of the from labels.
     */
    font?: string;
    /**
     * The format of the `from` labels. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) of IntlService.
     */
    format?: string;
    /**
     * The margin of the `from` labels. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The padding of the `from` labels. A numeric value sets all paddings.
     */
    padding?: Padding | number;
    /**
     * If set to `true`, the Chart displays the series `from` labels.
     * By default, the Chart series from labels are not displayed.
     */
    visible?: boolean;
}
