/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { Border, Margin, Padding, SeriesLabelsContentArgs, SeriesLabelsVisualArgs } from '../../common/property-types';
import { SeriesDefaultsLabelsFrom } from './labels.from.interface';
import { SeriesDefaultsLabelsTo } from './labels.to.interface';
/**
 * The configuration options of the series labels.
 */
export interface SeriesDefaultsLabels {
    /**
     * The background color of the labels. Accepts a valid CSS color string, including HEX and RGB.
     */
    background?: string;
    /**
     * The border of the labels.
     */
    border?: Border;
    /**
     * The text color of the labels. Accepts a valid CSS color string, including HEX and RGB.
     */
    color?: string;
    /**
     * The function which returns the Chart series labels content.
     * You can split the text into multiple lines by using line feed characters (`"\n"`).
     */
    content?: (e: SeriesLabelsContentArgs) => string;
    /**
     * The font style of the labels.
     */
    font?: string;
    /**
     * The format of the labels. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of IntlService.
     */
    format?: string;
    /**
     * The margin of the labels. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The padding of the labels. A numeric value sets all margins.
     */
    padding?: Padding | number;
    /**
     * The rotation angle of the labels. By default, the labels are not rotated.
     */
    rotation?: number;
    /**
     * If set to `true`, the Chart displays the series labels.
     * By default, the Chart series labels are not displayed.
     */
    visible?: boolean;
    /**
     * A function that can be used to create a custom visual for the labels.
     */
    visual?: (e: SeriesLabelsVisualArgs) => drawing.Element;
    /**
     * The Chart series `from` label configuration.
     * The Chart displays the series labels when either the [`seriesDefaults.labels.visible`]({% slug api_charts_seriesdefaultslabels %}#toc-visible) or
     * the [`seriesDefaults.labels.from.visible`]({% slug api_charts_seriesdefaultslabelsfrom %}#toc-visible) option is set to `true`.
     */
    from?: SeriesDefaultsLabelsFrom;
    /**
     * The Chart series `to` label configuration.
     * The Chart displays the series labels when either the [`seriesDefaults.labels.visible`]({% slug api_charts_seriesdefaultslabels %}#toc-visible) or
     * the [`seriesDefaults.labels.to.visible`]({% slug api_charts_seriesdefaultslabelsto %}#toc-visible) option is set to `true`.
     */
    to?: SeriesDefaultsLabelsTo;
}
