/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Border, Margin, Padding, SeriesLabelsContentArgs } from '../../common/property-types';
/**
 * The configuration options of the Chart series `to` labels.
 */
export interface SeriesDefaultsLabelsTo {
    /**
     * The background color of `to` lables. Accepts a valid CSS color string, including HEX and RGB.
     */
    background?: string;
    /**
     * The border of `to` labels.
     */
    border?: Border;
    /**
     * The text color of `to` labels. Accepts a valid CSS color string, including HEX and RGB.
     */
    color?: string;
    /**
     * The function which returns the `from` label content of the Chart series.
     * You can split the text into multiple lines by using the line feed characters (`"\n"`).
     */
    content?: (e: SeriesLabelsContentArgs) => string;
    /**
     * The font style of the `to` labels.
     */
    font?: string;
    /**
     * The format of the `to` labels. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of IntlService.
     */
    format?: string;
    /**
     * The margin of the `to` labels. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The padding of the `to` labels. A numeric value sets all paddings.
     */
    padding?: Padding | number;
    /**
     * If set to `true`, the Chart displays the `to` labels of the series.
     * By default, the `to` labels of the Chart series are not displayed.
     */
    visible?: boolean;
}
