/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Border, NoteLabelPosition, SeriesNoteContentArgs } from '../../common/property-types';
/**
 * The configuration options of the series notes label.
 */
export interface SeriesDefaultsNotesLabel {
    /**
     * The background color of the label. Accepts a valid CSS color string, including HEX and RGB.
     */
    background?: string;
    /**
     * The border of the label.
     */
    border?: Border;
    /**
     * The text color of the label. Accepts a valid CSS color string, including HEX and RGB.
     */
    color?: string;
    /**
     * The function which returns the label content.
     * You can split the text into multiple lines by using line feed characters (`"\n"`).
     */
    content?: (e: SeriesNoteContentArgs) => string;
    /**
     * The font style of the label.
     */
    font?: string;
    /**
     * The format for displaying the notes label. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of IntlService.
     * Contains one placeholder (`"{0}"`) which represents the axis value.
     */
    format?: string;
    /**
     * The position of the labels.
     */
    position?: NoteLabelPosition;
    /**
     * The rotation angle of the label. By default, the label is not rotated.
     */
    rotation?: number;
    /**
     * If set to `true`, the Chart displays the [`seriesDefaults`]({% slug api_charts_seriesdefaults %}) notes label.
     * By default, the [`seriesDefaults`]({% slug api_charts_seriesdefaults %}) notes label is visible.
     */
    visible?: boolean;
}
