/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { Border, HighlightLine, HighlightVisualArgs, HighlightToggleArgs } from '../../common/property-types';
import { MarkersHighlight } from './markers-highlight.interface';
/**
 * The configuration options of the series highlight.
 */
export interface SeriesHighlight {
    /**
     * The border of the highlighted Chart series.
     * The color is computed automatically from the base point color.
     * The border option is supported when [`series.type`]({% slug api_charts_series %}#toc-type) is set to
     * `"donut"`, `"bubble"`, `"pie"`, `"candlestick"`, or `"ohlc"`.
     */
    border?: Border;
    /**
     * The highlight color. Accepts a valid CSS color string, including HEX and RGB.
     * The color option is supported when [`series.type`]({% slug api_charts_series %}#toc-type) is set to `"donut"` or `"pie"`.
     */
    color?: string;
    /**
     * The line of the highlighted Chart series.
     * The color is computed automatically from the base point color.
     * The line option is supported when [`series.type`]({% slug api_charts_series %}#toc-type) is set to `"candlestick"` or `"ohlc"`.
     */
    line?: HighlightLine;
    /**
     * The opacity of the highlighted points.
     * The opacity option is supported when [`series.type`]({% slug api_charts_series %}#toc-type) is set to `"bubble"`, `"pie"`, or `"donut"`.
     */
    opacity?: number;
    /**
     * The opacity of the series when another series is highlighted.
     */
    inactiveOpacity?: number;
    /**
     * The appearance of the highlighted point markers.
     * The markers option is supported when [`series.type`]({% slug api_charts_series %}#toc-type) is set to `"line"`, `"area"`, `"scatter"`, `"scatterLine"`, or `"rangeArea"`.
     */
    markers?: MarkersHighlight;
    /**
     * A function for handling the toggling of the points highlight.
     */
    toggle?: (e: HighlightToggleArgs) => void;
    /**
     * If set to `true`, the Chart highlights the series when the user hovers over it with the mouse.
     * By default, the highlighting of the Chart series is enabled.
     */
    visible?: boolean;
    /**
     * A function for setting custom visuals for the point highlights.
     */
    visual?: (e: HighlightVisualArgs) => drawing.Element;
}
