/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Border, Margin, Padding, SeriesLabelsContentArgs } from '../../common/property-types';
/**
 * The configuration options of the series `from` labels.
 */
export interface SeriesLabelsFrom {
    /**
     * The background color of the `from` labels. Accepts a valid CSS color string, including HEW and RGB.
     */
    background?: string;
    /**
     * The border of the `from` labels.
     */
    border?: Border;
    /**
     * The text color of the `from` labels. Accepts a valid CSS color string, including HEX and RGB.
     */
    color?: string;
    /**
     * The function which returns the Chart series `from` label content.   *
     * The text can be split into multiple lines by using the line feed characters (`"\n"`).
     */
    content?: (e: SeriesLabelsContentArgs) => string;
    /**
     * The font style of the `from` labels.
     */
    font?: string;
    /**
     * The format of the `from` labels. Uses the IntlService [`format`]({% slug api_intl_intlservice %}#toc-format) method.
     */
    format?: string;
    /**
     * The margin of the `from` labels. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The padding of the `from` labels. A numeric value sets all paddings.
     */
    padding?: Padding | number;
    /**
     * The position of the `from` labels.
     *
     * - `"center"`&mdash;The label is positioned at the point center.
     * - `"insideBase"`&mdash;The label is positioned inside, near the base of the bar.
     * - `"insideEnd"`&mdash;The label is positioned inside, near the end of the point.
     * - `"outsideEnd"`&mdash;The label is positioned outside, near the end of the point.
     * - `"above"`&mdash;the label is positioned at the top of the marker. Applicable for `"rangeArea"` and `"verticalRangeArea"` series.
     * - `"below"`&mdash;the label is positioned at the bottom of the marker. Applicable for `"rangeArea"` and `"verticalRangeArea"` series.
     * - `"left"`&mdash;the label is positioned to the left of the marker. Applicable for `"rangeArea"` and `"verticalRangeArea"` series.
     * - `"right"`&mdash;the label is positioned to the right of the marker. Applicable for `"rangeArea"` and `"verticalRangeArea"` series.
     */
    position?: 'center' | 'insideBase' | 'insideEnd' | 'outsideEnd';
    /**
     * If set to `true`, the Chart displays the series `from` labels.
     * By default, the Chart series `from` labels are not displayed.
     */
    visible?: boolean;
}
