/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Border, Margin, Padding, SeriesLabelsContentArgs } from '../../common/property-types';
/**
 * The configuration options of the series `to` labels.
 */
export interface SeriesLabelsTo {
    /**
     * The background color of the `to` labels. Accepts a valid CSS color string, including HEW and RGB.
     */
    background?: string;
    /**
     * The border of the `to` labels.
     */
    border?: Border;
    /**
     * The text color of the `to` labels. Accepts a valid CSS color string, including HEX and RGB.
     */
    color?: string;
    /**
     * The function which returns the Chart series `to` label content.
     * You can split the text into multiple lines by using line feed characters (`"\n"`).
     */
    content?: (e: SeriesLabelsContentArgs) => string;
    /**
     * The font style of the `to` labels.
     */
    font?: string;
    /**
     * The format of the `to` labels. Uses [IntlService format]({% slug api_intl_intlservice %}#toc-format).
     */
    format?: string;
    /**
     * The margin of the `to` labels. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The padding of the `to` labels. A numeric value sets all paddings.
     */
    padding?: Padding | number;
    /**
     * The position of the `to` labels.
     *
     * The available options are:
     *
     * - `"center"`&mdash;The label is positioned at the point center.
     * - `"insideBase"`&mdash;The label is positioned inside, near the base of the bar.
     * - `"insideEnd"`&mdash;The label is positioned inside, near the end of the point.
     * - `"outsideEnd"`&mdash;The label is positioned outside, near the end of the point.
     * - `"above"`&mdash;The label is positioned at the top of the marker. Applicable for the RangeArea and VerticalRangeArea series.
     * - `"below"`&mdash;The label is positioned at the bottom of the marker. Applicable for the RangeArea and VerticalRangeArea series.
     * - `"left"`&mdash;The label is positioned to the left of the marker. Applicable for the RangeArea and VerticalRangeArea series.
     * - `"right"`&mdash;The label is positioned to the right of the marker. Applicable for the RangeArea and VerticalRangeArea series.
     */
    position?: 'center' | 'insideBase' | 'insideEnd' | 'outsideEnd';
    /**
     * If set to `true`, the Chart displays the series `to` labels.
     * By default, the Chart series `to` labels are not displayed.
     */
    visible?: boolean;
}
