/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { drawing } from '@progress/kendo-drawing';
import { Border, MarkersVisualArgs, MarkerType } from '../../common/property-types';
/**
 * The configuration options of the series markers.
 */
export interface SeriesMarkers {
    /**
     * The background color of the series markers.
     */
    background?: string;
    /**
     * The border of the markers.
     */
    border?: Border;
    /**
     * The rotation angle of the markers.
     */
    rotation?: number;
    /**
     * The marker size in pixels.
     */
    size?: number;
    /**
     * The border radius in pixels when `type` is set to `"roundedRect"`. Defaults to 1/5 of the marker size.
     */
    borderRadius?: number;
    /**
     * The shape of the series markers.
     */
    type?: MarkerType;
    /**
     * If set to `true`, the Chart displays the series markers.
     * By default, the Chart series markers are displayed.
     */
    visible?: boolean;
    /**
     * A function for creating a custom visual for the markers.
     */
    visual?: (e: MarkersVisualArgs) => drawing.Element;
    /**
     * The Chart series marker configuration for the `from` point. Supported for the RangeArea and VerticalRangeArea series.
     */
    from?: SeriesMarkers;
    /**
     * The Chart series marker configuration for the `to` point. Supported for the RangeArea and VerticalRangeArea series.
     */
    to?: SeriesMarkers;
}
