/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Border, Padding } from '../../common/property-types';
/**
 * The configuration options of the series tooltip.
 */
export interface SeriesTooltip {
    /**
     * The background color of the tooltip. Accepts a valid CSS color string, including HEX and RGB.
     */
    background?: string;
    /**
     * The border configuration options.
     */
    border?: Border;
    /**
     * The text color of the tooltip. Accepts a valid CSS color string, including HEX and RGB.
     */
    color?: string;
    /**
     * The font of the tooltip.
     */
    font?: string;
    /**
     * The format of the labels. Uses the [`format`]({% slug api_intl_intlservice %}#toc-format) method of `IntlService`.
     *
     * The Area, Bar, Column, Funnel, Pyramid, Line, and Pie are represented by `{0}` as the value placeholder.
     *
     * The Bubble chart type uses the following value placeholders: `{0}` - x value, `{1}` - y value, `{2}` - size value, and `{3}` - category name.
     *
     * The Scatter and ScatterLine chart types use the following value placeholders: `{0}` - x value and `{1}` - y value.
     *
     * The Candlestick and OHLC chart types use the following value placeholders: `{0}` - open value, `{1}` - high value, `{2}` - low value, `{3}` - close value, and `{4}` - category name.
     *
     * The RangeArea, RangeBar, and RangeColumn chart types utilize the following value placeholders: `{0}` - from value and `{1}` - to value.
     */
    format?: string;
    /**
     * The padding of the tooltip. A numeric value sets all paddings.
     */
    padding?: Padding | number;
    /**
     * If set to `true`, the Chart displays the series tooltip.
     * By default, the series tooltip is not displayed.
     */
    visible?: boolean;
}
