/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TrendlineForecast } from "../../common/property-types";
/**
 * The configuration options of the series trendlines.
 */
export interface SeriesTrendline {
    /**
     * The trendline forecast settings. By default, the trendline does not display a forecast.
     *
     * The forecast setting is supported for Linear Trendlines on date and scatter series.
     */
    forecast?: TrendlineForecast;
    /**
     * The number of intervals to take when calculating averages. The value should be an integer greater than 2.
     *
     * The period setting is supported only for Moving Average trendlines.
     */
    period?: number;
    /**
     * The order (degree) of the Polynomial trendline. The default value is 2.
     *
     * Accepted values are from 2 to 6:
     * * 2: a Quadratic polynomial trendline with a single extreme point (minimum or maximum) point.
     * * 3: a Cubic polynomial trendline with up to 2 extreme points.
     * * 4: a polynomial trendline of 4th degree with up to 3 extreme points.
     * * 5: a polynomial trendline of 5th degree with up to 4 extreme points.
     * * 6: a polynomial trendline of 6th degree with up to 5 extreme points.
     *
     */
    order?: number;
}
