/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Border, Margin, Padding } from '../common/property-types';
/**
 * The configuration options of the subtitle
 * ([see example]({% slug api_charts_subtitlecomponent %})).
 */
export interface Subtitle {
    /**
     * The alignment of the subtitle.
     *
     * By default, the subtitle has the same alignment as the title.
     *
     * The alignment options for subtitle include `center` for middle alignment, `left` for left alignment, and `right` for right alignment, allowing for flexible positioning of the subtitle.
     */
    align?: 'center' | 'left' | 'right';
    /**
     * The background color of the subtitle. Accepts a valid CSS color string, including HEX and RGB.
     */
    background?: string;
    /**
     * The border of the subtitle.
     */
    border?: Border;
    /**
     * The text color of the subtitle. Accepts a valid CSS color string, including HEX and RGB.
     */
    color?: string;
    /**
     * The font of the subtitle.
     */
    font?: string;
    /**
     * The margin of the subtitle. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The padding of the subtitle. A numeric value sets all paddings.
     */
    padding?: Padding | number;
    /**
     * The position of the subtitle.
     *
     * By default, the subtitle is placed in the same position as the title.
     *
     * The positioning options for subtitle include `bottom` for positioning at the bottom and `top` for positioning at the top, providing flexibility in the subtitle placement.
     */
    position?: 'top' | 'bottom';
    /**
     * The text of the chart subtitle. You can also set the text directly for a title with default options.
     *
     * You can split the text into multiple lines by using the line feed characters ("\n").
     */
    text?: string;
    /**
     * If set to `true`, the Chart displays the subtitle. By default, the subtitle is displayed.
     */
    visible?: boolean;
}
