/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { Border, Margin, Padding } from '../common/property-types';
/**
 * The configuration options of the title
 * ([see example]({% slug api_charts_titlecomponent %})).
 */
export interface Title {
    /**
     * The alignment of the title.
     * The alignment options for text include `center` for middle alignment, `left` for left alignment, and `right` for right alignment, allowing for flexible positioning of the title.
     */
    align?: 'center' | 'left' | 'right';
    /**
     * The background color of the title. Accepts a valid CSS color string, including HEX and RGB.
     */
    background?: string;
    /**
     * The border of the title.
     */
    border?: Border;
    /**
     * The text color of the title. Accepts a valid CSS color string, including HEX and RGB.
     */
    color?: string;
    /**
     * The font of the title.
     */
    font?: string;
    /**
     * The margin of the title. A numeric value sets all margins.
     */
    margin?: Margin | number;
    /**
     * The padding of the title. A numeric value sets all margins.
     */
    padding?: Padding | number;
    /**
     * The position of the title.
     * The positioning options for titles include `bottom` for positioning at the bottom and `top` for positioning at the top, providing flexibility in title placement.
     */
    position?: 'top' | 'bottom';
    /**
     * The text of the chart title. You can also set the text directly for a title with default options.
     * You can split the text into multiple lines by using the line feed characters ("\n").
     */
    text?: string;
    /**
     * The accessible description of the Chart.
     *
     * The description is announced by screen readers when the Chart is focused.
     */
    description?: string;
    /**
     * If set to `true`, the Chart displays the title. By default, the title is displayed.
     */
    visible?: boolean;
}
