/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../common/configuration.service';
import { SettingsComponent } from '../common/settings.component';
import { SankeyNodeDefaults, SankeyOffset } from './api-types';
import { FocusHighlight } from '@progress/kendo-charts';
import * as i0 from "@angular/core";
/**
 * The configuration options of the Sankey nodes
 * ([see example](slug:customization_sankey#toc-customizing-the-sankey-diagram-elements)).
 */
export declare class SankeyNodesComponent extends SettingsComponent implements SankeyNodeDefaults {
    configurationService: ConfigurationService;
    /**
     * The color type of the link.
     * The supported values are:
     * * `static`&mdash;The link color is static. The color is determined by the link's `color` option.
     * * `source`&mdash;The link color is the same as the source node color.
     * * `target`&mdash;The link color is the same as the target node color.
     *
     * @default 'static'
     */
    colorType?: 'static' | 'source' | 'target';
    color?: string;
    opacity?: number;
    offset?: SankeyOffset;
    padding?: number;
    width?: number;
    align?: 'stretch' | 'left' | 'right';
    focusHighlight?: FocusHighlight;
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<SankeyNodesComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SankeyNodesComponent, "kendo-sankey-nodes", never, { "colorType": { "alias": "colorType"; "required": false; }; "color": { "alias": "color"; "required": false; }; "opacity": { "alias": "opacity"; "required": false; }; "offset": { "alias": "offset"; "required": false; }; "padding": { "alias": "padding"; "required": false; }; "width": { "alias": "width"; "required": false; }; "align": { "alias": "align"; "required": false; }; "focusHighlight": { "alias": "focusHighlight"; "required": false; }; }, {}, never, never, true, never>;
}
