/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterContentChecked } from '@angular/core';
import { ConfigurationService } from '../common/configuration.service';
import { SettingsComponent } from '../common/settings.component';
import { SankeyLinkTooltipTemplateDirective } from './tooltip/link-tooltip-template.directive';
import { SankeyNodeTooltipTemplateDirective } from './tooltip/node-tooltip-template.directive';
import { SankeyTooltip } from '@progress/kendo-charts';
import { SankeyTooltipTemplateService } from './tooltip/tooltip-template.service';
import * as i0 from "@angular/core";
/**
 * The configuration options of the Sankey tooltip
 * ([see example]({% slug tooltip_sankey %})).
 */
export declare class SankeyTooltipComponent extends SettingsComponent implements SankeyTooltip, AfterContentChecked {
    configurationService: ConfigurationService;
    private templateService;
    /**
     * Indicates whether the tooltip will follow the mouse pointer.
     *
     * @default false
     */
    followPointer?: boolean;
    /**
     * Represents the delay of the tooltip displaying.
     * The delay is measured in milliseconds.
     *
     * @default 100
     */
    delay?: number;
    /**
     * The distance between the tooltip and the mouse pointer in pixels.
     * @default 12
     */
    offset: number;
    /**
     * If set to `true`, the Sankey displays the link and node tooltips.
     * @default false
     */
    visible: boolean;
    linkTooltipTemplate: SankeyLinkTooltipTemplateDirective;
    nodeTooltipTemplate: SankeyNodeTooltipTemplateDirective;
    constructor(configurationService: ConfigurationService, templateService: SankeyTooltipTemplateService);
    ngAfterContentChecked(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SankeyTooltipComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SankeyTooltipComponent, "kendo-sankey-tooltip", never, { "followPointer": { "alias": "followPointer"; "required": false; }; "delay": { "alias": "delay"; "required": false; }; "offset": { "alias": "offset"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; }, {}, ["linkTooltipTemplate", "nodeTooltipTemplate"], never, true, never>;
}
