/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { AfterViewInit, ElementRef, NgZone, Renderer2, TemplateRef } from '@angular/core';
import { LocalizationService } from '@progress/kendo-angular-l10n';
import { PopupService } from '@progress/kendo-angular-popup';
import { SankeyTooltipEvent } from '@progress/kendo-charts';
import { BaseTooltip } from '../../chart/tooltip/base-tooltip';
import { SankeyLinkTooltipTemplateContext } from './link-tooltip-template-context';
import { SankeyLinkTooltipTemplateDirective } from './link-tooltip-template.directive';
import { SankeyNodeTooltipTemplateContext } from './node-tooltip-template-context';
import { SankeyNodeTooltipTemplateDirective } from './node-tooltip-template.directive';
import { SankeyTooltipTemplateService } from './tooltip-template.service';
import { IntlService } from '@progress/kendo-angular-intl';
import { Subscription } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * @hidden
 */
export declare class SankeyTooltipPopupComponent extends BaseTooltip implements AfterViewInit {
    protected element: ElementRef;
    protected popupService: PopupService;
    protected templateService: SankeyTooltipTemplateService;
    protected localizationService: LocalizationService;
    protected intlService: IntlService;
    protected ngZone: NgZone;
    protected renderer: Renderer2;
    nodeTooltipTemplateRef: TemplateRef<any>;
    linkTooltipTemplateRef: TemplateRef<any>;
    nodeTooltipContext: SankeyNodeTooltipTemplateContext;
    linkTooltipContext: SankeyLinkTooltipTemplateContext;
    defaultNodeTooltipTemplate: SankeyNodeTooltipTemplateDirective;
    defaultLinkTooltipTemplate: SankeyLinkTooltipTemplateDirective;
    templateRef: TemplateRef<any>;
    animate: boolean;
    wrapperClass: string;
    tooltipUnitFormat: string;
    offset: number;
    isNode: boolean;
    isLink: boolean;
    arrowIcon: import("@progress/kendo-svg-icons").SVGIcon;
    textStyle: {
        margin: string;
    };
    tooltipStyle: {
        display: string;
        alignItems: string;
    };
    protected subscriptions: Subscription;
    protected rtl: boolean;
    constructor(element: ElementRef, popupService: PopupService, templateService: SankeyTooltipTemplateService, localizationService: LocalizationService, intlService: IntlService, ngZone: NgZone, renderer: Renderer2);
    protected onInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    show(e: SankeyTooltipEvent): void;
    tooltipAnchor(e: SankeyTooltipEvent): {
        left: number;
        top: number;
    };
    formatUnits(value: number): string;
    protected rtlChange(): void;
    protected setDirection(): void;
    protected get isRTL(): boolean;
    static ɵfac: i0.ɵɵFactoryDeclaration<SankeyTooltipPopupComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SankeyTooltipPopupComponent, "kendo-sankey-tooltip-popup", never, { "animate": { "alias": "animate"; "required": false; }; "wrapperClass": { "alias": "wrapperClass"; "required": false; }; "tooltipUnitFormat": { "alias": "tooltipUnitFormat"; "required": false; }; "offset": { "alias": "offset"; "required": false; }; }, {}, never, never, true, never>;
}
