/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ConfigurationService } from '../common/configuration.service';
import { SettingsComponent } from '../common/settings.component';
import { CategoryAxis, Pane, Series } from '../common/property-types';
import { Navigator, NavigatorHint, NavigatorSelect } from './option-types';
import * as i0 from "@angular/core";
/**
 * The configuration options of the navigator
 * ([see runnable example](slug:overview_stockchart_charts)).
 *
 * @example
 * ```ts-no-run
 * _@Component({
 *     selector: 'my-app',
 *       template: `
 *         <kendo-stockchart (navigatorFilter)="onNavigatorFilter($event)">
 *             <kendo-chart-series>
 *                <kendo-chart-series-item
 *                type="candlestick"
 *                 [data]="seriesData"
 *                 openField="Open"
 *                 closeField="Close"
 *                 lowField="Low"
 *                 highField="High"
 *                 categoryField="Date">
 *             </kendo-chart-series-item>
 *          </kendo-chart-series>
 *          <kendo-chart-navigator
 *            [categoryAxis]="categoryAxisOptions"
 *            [hint]="hintOptions"
 *            [pane]="paneOptions"
 *            [visible]="isVisible">
 *            <kendo-chart-navigator-select [from]="from" [to]="to">
 *            </kendo-chart-navigator-select>
 *            <kendo-chart-navigator-series>
 *              <kendo-chart-navigator-series-item type="area" [data]="navigatorData" field="Close" categoryField="Date">
 *              </kendo-chart-navigator-series-item>
 *           </kendo-chart-navigator-series>
 *          </kendo-chart-navigator>
 *        </kendo-stockchart>
 *        <br /><br />
 *        <button kendoButton (click)="isVisible = !isVisible">Toggle Navigator</button>
 *    `
 * })
 * ```
 */
export declare class NavigatorComponent extends SettingsComponent implements Navigator {
    configurationService: ConfigurationService;
    position: 'top' | 'bottom';
    visible: boolean;
    categoryAxis: CategoryAxis;
    hint: NavigatorHint;
    pane: Pane;
    select: NavigatorSelect;
    series: Series | Series[];
    constructor(configurationService: ConfigurationService);
    static ɵfac: i0.ɵɵFactoryDeclaration<NavigatorComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NavigatorComponent, "kendo-chart-navigator", never, { "position": { "alias": "position"; "required": false; }; "visible": { "alias": "visible"; "required": false; }; "categoryAxis": { "alias": "categoryAxis"; "required": false; }; "hint": { "alias": "hint"; "required": false; }; "pane": { "alias": "pane"; "required": false; }; "select": { "alias": "select"; "required": false; }; "series": { "alias": "series"; "required": false; }; }, {}, never, never, true, never>;
}
